@@ -61,20 +61,11 @@ enum AstyleOptions {
     AS_INDENT_USES_TABS = 0x40000000,
     AS_DEFAULT = AS_LINUX | AS_BRACKETS_LINUX | AS_INDENT_PREPROCESSORS,
     AS_ALL_INDENT_OPTIONS = AS_INDENT_CLASS | AS_INDENT_BRACKETS | AS_INDENT_SWITCHES | AS_INDENT_NAMESPACES |
-                            AS_INDENT_CASE |
-                            AS_INDENT_LABELS |
-                            AS_INDENT_BLOCKS |
-                            AS_INDENT_PREPROCESSORS |
-                            AS_MAX_INSTATEMENT_INDENT |
-                            AS_MIN_COND_INDENT,
+        AS_INDENT_CASE | AS_INDENT_LABELS | AS_INDENT_BLOCKS | AS_INDENT_PREPROCESSORS | AS_MAX_INSTATEMENT_INDENT |
+        AS_MIN_COND_INDENT,
     AS_ALL_FORMAT_OPTIONS = AS_BREAK_BLOCKS | AS_PAD_PARENTHESIS | AS_BREAK_BLOCKS_ALL | AS_PAD_PARENTHESIS_OUT |
-                            AS_BREAK_ELSEIF |
-                            AS_PAD_PARENTHESIS_IN |
-                            AS_PAD_OPER |
-                            AS_UNPAD_PARENTHESIS |
-                            AS_ONE_LINE_KEEP_STATEMENT |
-                            AS_FILL_EMPTY_LINES |
-                            AS_ONE_LINE_KEEP_BLOCKS,
+        AS_BREAK_ELSEIF | AS_PAD_PARENTHESIS_IN | AS_PAD_OPER | AS_UNPAD_PARENTHESIS | AS_ONE_LINE_KEEP_STATEMENT |
+        AS_FILL_EMPTY_LINES | AS_ONE_LINE_KEEP_BLOCKS,
 };
 
 enum FormatterEngine {
@@ -112,6 +103,7 @@ enum ClangFormatStyle {
     kSpacesInParentheses = (1 << 21),
     kAllowShortFunctionsOnASingleLine = (1 << 22),
     kPointerAlignmentRight = (1 << 23),
+    kClangFormatFile = (1 << 24),
 };
 
 enum ClangBreakBeforeBraceOpt {
