@@ -4,7 +4,7 @@ PHPEntityKeyword::PHPEntityKeyword() {}
 
 PHPEntityKeyword::~PHPEntityKeyword() {}
 
-wxString PHPEntityKeyword::FormatPhpDoc() const { return ""; }
+wxString PHPEntityKeyword::FormatPhpDoc(const CommentConfigData& data) const { return ""; }
 void PHPEntityKeyword::FromResultSet(wxSQLite3ResultSet& res) {}
 wxString PHPEntityKeyword::GetDisplayName() const { return m_shortName; }
 bool PHPEntityKeyword::Is(eEntityType type) const { return type == kEntityTypeKeyword; }
