@@ -12,12 +12,13 @@
 #include "PHPEntityFunctionAlias.h"
 #include <wx/tokenzr.h>
 #include "fileextmanager.h"
+#include <algorithm>
 
 wxDEFINE_EVENT(wxPHP_PARSE_STARTED, clParseEvent);
 wxDEFINE_EVENT(wxPHP_PARSE_ENDED, clParseEvent);
 wxDEFINE_EVENT(wxPHP_PARSE_PROGRESS, clParseEvent);
 
-static wxString PHP_SCHEMA_VERSION = "9.0.1";
+static wxString PHP_SCHEMA_VERSION = "9.3.0.1";
 
 //------------------------------------------------
 // Metadata table
@@ -115,6 +116,7 @@ const static wxString CREATE_VARIABLES_TABLE_SQL =
     "FULLNAME TEXT, "                           // Fullname with scope
     "SCOPE TEXT, "                              // Usually, this means the namespace\class
     "TYPEHINT TEXT, "                           // the Variable type hint
+    "DEFAULT_VALUE TEXT, "                      // Default value
     "FLAGS INTEGER DEFAULT 0, "
     "DOC_COMMENT TEXT, "
     "LINE_NUMBER INTEGER NOT NULL DEFAULT 0, "
@@ -129,6 +131,22 @@ const static wxString CREATE_VARIABLES_TABLE_SQL_IDX3 =
 const static wxString CREATE_VARIABLES_TABLE_SQL_IDX4 =
     "CREATE INDEX IF NOT EXISTS VARIABLES_TABLE_IDX_4 ON VARIABLES_TABLE(FUNCTION_ID)";
 
+//------------------------------------------------
+// Variables table
+//------------------------------------------------
+const static wxString CREATE_PHPDOC_VAR_TABLE_SQL =
+    "CREATE TABLE IF NOT EXISTS PHPDOC_VAR_TABLE(ID INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT, "
+    "SCOPE_ID INTEGER NOT NULL DEFAULT -1, " // for global variable or class member this will be the scope_id parent id
+    "NAME TEXT, "                            // the name
+    "TYPE TEXT, "                            // the type, full path
+    "LINE_NUMBER INTEGER NOT NULL DEFAULT 0, "
+    "FILE_NAME TEXT )";
+
+const static wxString CREATE_PHPDOC_VAR_TABLE_SQL_IDX1 =
+    "CREATE INDEX IF NOT EXISTS PHPDOC_VAR_TABLE_SQL_IDX1 ON PHPDOC_VAR_TABLE(SCOPE_ID)";
+const static wxString CREATE_PHPDOC_VAR_TABLE_SQL_IDX2 =
+    "CREATE INDEX IF NOT EXISTS PHPDOC_VAR_TABLE_SQL_IDX2 ON PHPDOC_VAR_TABLE(FILE_NAME)";
+
 //------------------------------------------------
 // Files table
 //------------------------------------------------
@@ -156,11 +174,15 @@ PHPEntityBase::Ptr_t PHPLookupTable::FindMemberOf(wxLongLong parentDbId, const w
         std::set<wxLongLong> parentsVisited;
 
         DoGetInheritanceParentIDs(scope, parents, parentsVisited, flags & kLookupFlags_Parent);
+        std::reverse(parents.begin(), parents.end());
 
         // Parents should now contain an ordered list of all the inheritance
         for(size_t i = 0; i < parents.size(); ++i) {
             PHPEntityBase::Ptr_t match = DoFindMemberOf(parents.at(i), exactName);
             if(match) {
+                PHPEntityBase::List_t matches;
+                matches.push_back(match);
+                DoFixVarsDocComment(matches, parentDbId);
                 return match;
             }
         }
@@ -245,6 +267,7 @@ void PHPLookupTable::CreateSchema()
         m_db.ExecuteUpdate("drop table if exists FUNCTION_ALIAS_TABLE");
         m_db.ExecuteUpdate("drop table if exists VARIABLES_TABLE");
         m_db.ExecuteUpdate("drop table if exists FILES_TABLE");
+        m_db.ExecuteUpdate("drop table if exists PHPDOC_VAR_TABLE");
     }
 
     try {
@@ -283,6 +306,11 @@ void PHPLookupTable::CreateSchema()
         m_db.ExecuteUpdate(CREATE_VARIABLES_TABLE_SQL_IDX3);
         m_db.ExecuteUpdate(CREATE_VARIABLES_TABLE_SQL_IDX4);
 
+        // phpdoc var table
+        m_db.ExecuteUpdate(CREATE_PHPDOC_VAR_TABLE_SQL);
+        m_db.ExecuteUpdate(CREATE_PHPDOC_VAR_TABLE_SQL_IDX1);
+        m_db.ExecuteUpdate(CREATE_PHPDOC_VAR_TABLE_SQL_IDX2);
+
         // Files
         m_db.ExecuteUpdate(CREATE_FILES_TABLE_SQL);
         m_db.ExecuteUpdate(CREATE_FILES_TABLE_SQL_IDX1);
@@ -448,6 +476,10 @@ PHPLookupTable::DoFindMemberOf(wxLongLong parentDbId, const wxString& exactName,
                 match->FromResultSet(res);
                 matches.push_back(match);
             }
+
+            // Fix variables type using the PHPDOC_VAR_TABLE content for this class
+            DoFixVarsDocComment(matches, parentDbId);
+
             if(matches.empty() || matches.size() > 1) {
                 return PHPEntityBase::Ptr_t(NULL);
             } else {
@@ -582,6 +614,9 @@ PHPEntityBase::List_t PHPLookupTable::FindChildren(wxLongLong parentId, size_t f
         std::set<wxLongLong> parentsVisited;
 
         DoGetInheritanceParentIDs(scope, parents, parentsVisited, flags & kLookupFlags_Parent);
+        // Reverse the order of the parents
+        std::reverse(parents.begin(), parents.end());
+
         for(size_t i = 0; i < parents.size(); ++i) {
             DoFindChildren(matches, parents.at(i), flags, nameHint);
         }
@@ -636,105 +671,6 @@ wxString PHPLookupTable::EscapeWildCards(const wxString& str)
 
 void PHPLookupTable::DoAddLimit(wxString& sql) { sql << " LIMIT " << m_sizeLimit; }
 
-void PHPLookupTable::RecreateSymbolsDatabase(const wxArrayString& files, eUpdateMode updateMode, bool parseFuncBodies)
-{
-    try {
-
-        {
-            clParseEvent event(wxPHP_PARSE_STARTED);
-            event.SetTotalFiles(files.GetCount());
-            event.SetCurfileIndex(0);
-            EventNotifier::Get()->AddPendingEvent(event);
-        }
-
-        wxStopWatch sw;
-        sw.Start();
-
-        m_db.Begin();
-        for(size_t i = 0; i < files.GetCount(); ++i) {
-            {
-                clParseEvent event(wxPHP_PARSE_PROGRESS);
-                event.SetTotalFiles(files.GetCount());
-                event.SetCurfileIndex(i);
-                event.SetFileName(files.Item(i));
-                EventNotifier::Get()->AddPendingEvent(event);
-            }
-
-            wxFileName fnFile(files.Item(i));
-            bool reParseNeeded(true);
-
-            if(updateMode == kUpdateMode_Fast) {
-                // Check to see if we need to re-parse this file
-                // and store it to the database
-
-                if(!fnFile.Exists()) {
-                    reParseNeeded = false;
-                } else {
-                    time_t lastModifiedOnDisk = fnFile.GetModificationTime().GetTicks();
-                    wxLongLong lastModifiedInDB = GetFileLastParsedTimestamp(fnFile);
-                    if(lastModifiedOnDisk <= lastModifiedInDB.ToLong()) {
-                        reParseNeeded = false;
-                    }
-                }
-            }
-
-            // Ensure that the file exists
-            if(!fnFile.Exists()) {
-                reParseNeeded = false;
-            }
-
-            // Parse only valid PHP files
-            if(FileExtManager::GetType(fnFile.GetFullName()) != FileExtManager::TypePhp) {
-                reParseNeeded = false;
-            }
-            
-            if(reParseNeeded) {
-                // For performance reaons, load the file into memory and then parse it
-                wxFileName fnSourceFile(files.Item(i));
-                wxString content;
-                if(!FileUtils::ReadFileContent(fnSourceFile, content, wxConvISO8859_1)) {
-                    CL_WARNING("PHP: Failed to read file: %s for parsing", fnSourceFile.GetFullPath());
-                    continue;
-                }
-                PHPSourceFile sourceFile(content);
-                sourceFile.SetFilename(fnSourceFile);
-                sourceFile.SetParseFunctionBody(parseFuncBodies);
-                sourceFile.Parse();
-                UpdateSourceFile(sourceFile, false);
-            }
-        }
-        m_db.Commit();
-        long elapsedMs = sw.Time();
-        wxString message;
-        message << _("PHP: parsed ") << files.GetCount() << " in " << elapsedMs << " milliseconds";
-        CL_DEBUGS(message);
-
-        {
-            clParseEvent event(wxPHP_PARSE_ENDED);
-            event.SetTotalFiles(files.GetCount());
-            event.SetCurfileIndex(files.GetCount());
-            EventNotifier::Get()->AddPendingEvent(event);
-        }
-
-    } catch(wxSQLite3Exception& e) {
-        try {
-            m_db.Rollback();
-
-        } catch(...) {
-        }
-
-        {
-            // always make sure that the end event is sent
-            clParseEvent event(wxPHP_PARSE_ENDED);
-            event.SetTotalFiles(files.GetCount());
-            event.SetCurfileIndex(files.GetCount());
-            EventNotifier::Get()->AddPendingEvent(event);
-        }
-
-        CL_WARNING("PHPLookupTable::UpdateSourceFiles: %s", e.GetMessage());
-    }
-}
-
 void PHPLookupTable::DoAddNameFilter(wxString& sql, const wxString& nameHint, size_t flags)
 {
     wxString name = nameHint;
@@ -872,6 +808,14 @@ void PHPLookupTable::DeleteFileEntries(const wxFileName& filename, bool autoComm
             st.ExecuteUpdate();
         }
 
+        {
+            wxString sql;
+            sql << "delete from PHPDOC_VAR_TABLE where FILE_NAME=:FILE_NAME";
+            wxSQLite3Statement st = m_db.PrepareStatement(sql);
+            st.Bind(st.GetParamIndex(":FILE_NAME"), filename.GetFullPath());
+            st.ExecuteUpdate();
+        }
+
         if(autoCommit) m_db.Commit();
     } catch(wxSQLite3Exception& e) {
         if(autoCommit) m_db.Rollback();
@@ -991,13 +935,13 @@ void PHPLookupTable::DoFindChildren(PHPEntityBase::List_t& matches,
 
                 bool isConst = match->Cast<PHPEntityVariable>()->IsConst();
                 bool isStatic = match->Cast<PHPEntityVariable>()->IsStatic();
-                if((isStatic || isConst) && CollectingStatics(flags)) {
-                    matches.push_back(match);
-
-                } else if(!isStatic && !isConst && !CollectingStatics(flags)) {
+                bool bAddIt = ((isStatic || isConst) && CollectingStatics(flags)) ||
+                              (!isStatic && !isConst && !CollectingStatics(flags));
+                if(bAddIt) {
                     matches.push_back(match);
                 }
             }
+            DoFixVarsDocComment(matches, parentId);
         }
 
     } catch(wxSQLite3Exception& e) {
@@ -1343,3 +1287,32 @@ PHPEntityBase::List_t PHPLookupTable::FindSymbol(const wxString& name)
     }
     return matches;
 }
+
+void PHPLookupTable::DoFixVarsDocComment(PHPEntityBase::List_t& matches, wxLongLong parentId)
+{
+    // Load all PHPDocVar belonged to this class
+    PHPDocVar::Map_t docs;
+    wxString sql;
+    sql << "SELECT * from PHPDOC_VAR_TABLE WHERE SCOPE_ID=" << parentId;
+    DoAddLimit(sql);
+    wxSQLite3Statement st = m_db.PrepareStatement(sql);
+    wxSQLite3ResultSet res = st.ExecuteQuery();
+
+    while(res.NextRow()) {
+        PHPDocVar::Ptr_t var(new PHPDocVar());
+        var->FromResultSet(res);
+        docs.insert(std::make_pair(var->GetName(), var));
+    }
+
+    // Let the PHPDOC table content override the matches' type
+    std::for_each(matches.begin(), matches.end(), [&](PHPEntityBase::Ptr_t match) {
+        if(match->Is(kEntityTypeVariable)) {
+            if(docs.count(match->GetShortName())) {
+                PHPDocVar::Ptr_t docvar = docs.find(match->GetShortName())->second;
+                if(!docvar->GetType().IsEmpty()) {
+                    match->Cast<PHPEntityVariable>()->SetTypeHint(docvar->GetType());
+                }
+            }
+        }
+    });
+}
