@@ -46,6 +46,7 @@ class WXDLLIMPEXP_CL PHPSourceFile
     bool m_reachedEOF;
     // aliases defined by the 'use' operator
     std::map<wxString, wxString> m_aliases;
+    PHPSourceFile* m_converter;
 
 public:
     typedef wxSharedPtr<PHPSourceFile> Ptr_t;
@@ -56,13 +57,18 @@ protected:
      * read the "..." and create a variable hint from it
      */
     bool ReadVariableInitialization(PHPEntityBase::Ptr_t var);
-    
+
     /**
      * @brief calls phpLexerNextToken. Use this call instead of the global phpLexerNextToken
      * since this function will handle all PHP comments found
      */
     bool NextToken(phpLexerToken& token);
 
+    /**
+     * @brief return the previous token
+     */
+    phpLexerToken& GetPreviousToken();
+
     /**
      * @brief read until we found 'delim' (consume it)
      */
@@ -80,7 +86,7 @@ protected:
      * @param tokens [output]
      */
     bool ReadExpression(wxString& expression);
-    
+
     /**
      * @brief unget the token
      */
@@ -102,41 +108,45 @@ protected:
      */
     wxString ReadType();
     
+    /**
+     * @brief PHP7 style: read the return value
+     */
+    wxString ReadFunctionReturnValueFromSignature();
+    
     /**
      * @brief read the value that comes after the 'extends' keyword
      */
     wxString ReadExtends();
-    
+
     /**
      * @brief read the tokens after the implements keyword
      */
     void ReadImplements(wxArrayString& impls);
-    
-    
+
     /**
      * @brief parse 'use' statements (outer scope, for aliasing)
      */
     void OnUse();
-    
+
     /**
      * @brief parse 'use' statements inside class (usually this is done for 'traits')
      */
     void OnUseTrait();
-    
+
     /**
      * @brief we are looking at a case like:
-     * use A, B { 
+     * use A, B {
      *  B::bigTalk as talk;
      * }
      * parse the inner block and scan for aliases
      */
     void ParseUseTraitsBody();
-    
+
     /**
      * @brief found 'foreach' statement
      */
     void OnForEach();
-    
+
     /**
      * @brief 'namespace' keyword found
      */
@@ -146,12 +156,12 @@ protected:
      * @brief 'function' keyword found
      */
     void OnFunction();
-    
+
     /**
      * @brief found catch keyword
      */
     void OnCatch();
-    
+
     /**
      * @brief found a global variable
      */
@@ -166,7 +176,7 @@ protected:
      * @brief a define keyword was found
      */
     void OnDefine(const phpLexerToken& tok);
-    
+
     /**
      * @brief found constant
      */
@@ -216,19 +226,26 @@ protected:
 public:
     PHPSourceFile(const wxFileName& filename);
     PHPSourceFile(const wxString& content);
-    
+
     virtual ~PHPSourceFile();
     
+    /**
+     * @brief use a different PHPSourceFile class for converting types to their 
+     * absolute path
+     * @param converter
+     */
+    void SetTypeAbsoluteConverter(PHPSourceFile* converter) { m_converter = converter; }
+    
     /**
      * @brief check if we are inside a PHP block at the end of the given buffer
      */
     static bool IsInPHPSection(const wxString& buffer);
-    
+
     /**
      * @brief return list of aliases (their short name) that appears on this file
      */
     PHPEntityBase::List_t GetAliases() const;
-    
+
     /**
      * @brief return list of defines defined in this source file
      */
