@@ -29,8 +29,9 @@
 #include "cppwordscanner.h"
 #include "stringaccessor.h"
 #include "dirsaver.h"
+#include "ctags_manager.h"
 
-CppWordScanner::CppWordScanner(const wxString &fileName)
+CppWordScanner::CppWordScanner(const wxString& fileName)
     : m_filename(fileName)
     , m_offset(0)
 {
@@ -41,7 +42,7 @@ CppWordScanner::CppWordScanner(const wxString &fileName)
     wxFFile thefile(m_filename, wxT("rb"));
     if(thefile.IsOpened()) {
         m_text.Clear();
-        thefile.ReadAll( &m_text, fontEncConv );
+        thefile.ReadAll(&m_text, fontEncConv);
         if(m_text.IsEmpty()) {
             // Try another converter
             fontEncConv = wxFONTENCODING_UTF8;
@@ -53,20 +54,15 @@ CppWordScanner::CppWordScanner(const wxString &fileName)
 
 CppWordScanner::CppWordScanner(const wxString& fileName, const wxString& text, int offset)
     : m_filename(fileName)
-    , m_text    (text.c_str())
-    , m_offset  (offset)
+    , m_text(text.c_str())
+    , m_offset(offset)
 {
     doInit();
 }
 
-CppWordScanner::~CppWordScanner()
-{
-}
+CppWordScanner::~CppWordScanner() {}
 
-void CppWordScanner::FindAll(CppTokensMap &tokensMap)
-{
-    doFind("", tokensMap, wxNOT_FOUND, wxNOT_FOUND);
-}
+void CppWordScanner::FindAll(CppTokensMap& tokensMap) { doFind("", tokensMap, wxNOT_FOUND, wxNOT_FOUND); }
 
 void CppWordScanner::Match(const wxString& word, CppTokensMap& l)
 {
@@ -86,79 +82,79 @@ void CppWordScanner::doFind(const wxString& filter, CppTokensMap& l, int from, i
     StringAccessor accessor(m_text);
     CppToken token;
     int lineNo(0);
-    
+
     // set the scan range
-    size_t f = (from == wxNOT_FOUND) ? 0             : from;
-    size_t t = (to   == wxNOT_FOUND) ? m_text.size() : to;
+    size_t f = (from == wxNOT_FOUND) ? 0 : from;
+    size_t t = (to == wxNOT_FOUND) ? m_text.size() : to;
 
     // sanity
-    if(f > m_text.size() || t > m_text.size())
-        return;
+    if(f > m_text.size() || t > m_text.size()) return;
 
-    for (size_t i=f; i<t; i++) {
+    for(size_t i = f; i < t; i++) {
         char ch = accessor.safeAt(i);
 
         // Keep track of line numbers
-        if(accessor.match("\n", i) && (state == STATE_NORMAL || state == STATE_PRE_PROCESSING || state == STATE_CPP_COMMENT || state == STATE_C_COMMENT)) {
+        if(accessor.match("\n", i) && (state == STATE_NORMAL || state == STATE_PRE_PROCESSING ||
+                                       state == STATE_CPP_COMMENT || state == STATE_C_COMMENT)) {
             lineNo++;
         }
 
-        switch (state) {
+        switch(state) {
 
         case STATE_NORMAL:
-            if (accessor.match("#", i)) {
+            if(accessor.match("#", i)) {
 
-                if (    i == 0 ||                       // satrt of document
-                        accessor.match("\n", i-1)) {    // we are at start of line
+                if(i == 0 ||                      // satrt of document
+                   accessor.match("\n", i - 1)) { // we are at start of line
                     state = STATE_PRE_PROCESSING;
                 }
-            } else if (accessor.match("//", i)) {
+            } else if(accessor.match("//", i)) {
 
                 // C++ comment, advance i
                 state = STATE_CPP_COMMENT;
                 i++;
 
-            } else if (accessor.match("/*", i)) {
+            } else if(accessor.match("/*", i)) {
 
                 // C comment
                 state = STATE_C_COMMENT;
                 i++;
 
-            } else if (accessor.match("'", i)) {
+            } else if(accessor.match("'", i)) {
 
                 // single quoted string
                 state = STATE_SINGLE_STRING;
 
-            } else if (accessor.match("\"", i)) {
+            } else if(accessor.match("\"", i)) {
 
                 // dbouble quoted string
                 state = STATE_DQ_STRING;
 
-            } else if ( accessor.isWordChar(ch) ) {
+            } else if(accessor.isWordChar(ch)) {
 
                 // is valid C++ word?
-                token.append( ch );
-                if (token.getOffset() == wxString::npos) {
-                    token.setOffset( i + m_offset );
+                token.append(ch);
+                if(token.getOffset() == wxString::npos) {
+                    token.setOffset(i + m_offset);
                 }
             } else {
 
-                if (token.getName().empty() == false) {
+                if(token.getName().empty() == false) {
 
-                    if ((int)token.getName().at(0) >= 48 && (int)token.getName().at(0) <= 57) {
+                    if((int)token.getName().at(0) >= 48 && (int)token.getName().at(0) <= 57) {
                         token.reset();
                     } else {
-                        //dont add C++ key words
+                        // dont add C++ key words
                         wxString tmpName(token.getName());
-                        
-                        if (m_keywords.count(tmpName) == 0) {
-                            
+
+                        if(m_keywords.count(tmpName) == 0) {
+
                             token.setFilename(m_filename);
                             token.setLineNumber(lineNo);
-                            
+
                             // Ok, we are not a number!
                             // filter out non matching words
-                            if (filter.empty() || filter == token.getName()) {
+                            if(filter.empty() || filter == token.getName()) {
                                 l.addToken(token);
                             }
                         }
@@ -169,47 +165,48 @@ void CppWordScanner::doFind(const wxString& filter, CppTokensMap& l, int from, i
 
             break;
         case STATE_PRE_PROCESSING:
-            // if the char before the \n is \ (backslash) or \r\ (CR followed by backslash) remain in pre-processing state
-            if ( accessor.match("\n", i) && (!accessor.match("\\", i-1) && !accessor.match("\\\r", i-2)) ) {
+            // if the char before the \n is \ (backslash) or \r\ (CR followed by backslash) remain in pre-processing
+            // state
+            if(accessor.match("\n", i) && (!accessor.match("\\", i - 1) && !accessor.match("\\\r", i - 2))) {
                 // no wrap
                 state = STATE_NORMAL;
 
-            } else if ( accessor.match("//", i)) {
+            } else if(accessor.match("//", i)) {
                 // C++ comment, advance i
                 state = STATE_CPP_COMMENT;
                 i++;
             }
             break;
         case STATE_C_COMMENT:
-            if ( accessor.match("*/", i)) {
+            if(accessor.match("*/", i)) {
                 state = STATE_NORMAL;
                 i++;
             }
             break;
         case STATE_CPP_COMMENT:
-            if ( accessor.match("\n", i)) {
+            if(accessor.match("\n", i)) {
                 state = STATE_NORMAL;
             }
             break;
         case STATE_DQ_STRING:
-            if (accessor.match("\\\"", i)) {
-                //escaped string
+            if(accessor.match("\\\"", i)) {
+                // escaped string
                 i++;
             } else if(accessor.match("\\", i)) {
                 i++;
-            } else if (accessor.match("\"", i)) {
+            } else if(accessor.match("\"", i)) {
                 state = STATE_NORMAL;
             }
             break;
         case STATE_SINGLE_STRING:
-            if (accessor.match("\\'", i)) {
-                //escaped single string
+            if(accessor.match("\\'", i)) {
+                // escaped single string
                 i++;
 
             } else if(accessor.match("\\", i)) {
                 i++;
 
-            } else if (accessor.match("'", i)) {
+            } else if(accessor.match("'", i)) {
                 state = STATE_NORMAL;
             }
             break;
@@ -224,76 +221,76 @@ CppToken::List_t CppWordScanner::tokenize()
     CppToken token;
     int lineNo(0);
     CppToken::List_t allTokens;
-    
+
     // set the scan range
     size_t f = 0;
     size_t t = m_text.size();
 
     // sanity
-    if(f > m_text.size() || t > m_text.size())
-        return CppToken::List_t();
+    if(f > m_text.size() || t > m_text.size()) return CppToken::List_t();
 
-    for (size_t i=f; i<t; i++) {
+    for(size_t i = f; i < t; i++) {
         char ch = accessor.safeAt(i);
 
         // Keep track of line numbers
-        if(accessor.match("\n", i) && (state == STATE_NORMAL || state == STATE_PRE_PROCESSING || state == STATE_CPP_COMMENT || state == STATE_C_COMMENT)) {
+        if(accessor.match("\n", i) && (state == STATE_NORMAL || state == STATE_PRE_PROCESSING ||
+                                       state == STATE_CPP_COMMENT || state == STATE_C_COMMENT)) {
             lineNo++;
         }
 
-        switch (state) {
+        switch(state) {
 
         case STATE_NORMAL:
-            if (accessor.match("#", i)) {
+            if(accessor.match("#", i)) {
 
-                if (    i == 0 ||                       // satrt of document
-                        accessor.match("\n", i-1)) {    // we are at start of line
+                if(i == 0 ||                      // satrt of document
+                   accessor.match("\n", i - 1)) { // we are at start of line
                     state = STATE_PRE_PROCESSING;
                 }
-            } else if (accessor.match("//", i)) {
+            } else if(accessor.match("//", i)) {
 
                 // C++ comment, advance i
                 state = STATE_CPP_COMMENT;
                 i++;
 
-            } else if (accessor.match("/*", i)) {
+            } else if(accessor.match("/*", i)) {
 
                 // C comment
                 state = STATE_C_COMMENT;
                 i++;
 
-            } else if (accessor.match("'", i)) {
+            } else if(accessor.match("'", i)) {
 
                 // single quoted string
                 state = STATE_SINGLE_STRING;
 
-            } else if (accessor.match("\"", i)) {
+            } else if(accessor.match("\"", i)) {
 
                 // dbouble quoted string
                 state = STATE_DQ_STRING;
 
-            } else if ( accessor.isWordChar(ch) ) {
+            } else if(accessor.isWordChar(ch)) {
 
                 // is valid C++ word?
-                token.append( ch );
-                if (token.getOffset() == wxString::npos) {
-                    token.setOffset( i + m_offset );
+                token.append(ch);
+                if(token.getOffset() == wxString::npos) {
+                    token.setOffset(i + m_offset);
                 }
             } else {
 
-                if (token.getName().empty() == false) {
+                if(token.getName().empty() == false) {
 
-                    if ((int)token.getName().at(0) >= 48 && (int)token.getName().at(0) <= 57) {
+                    if((int)token.getName().at(0) >= 48 && (int)token.getName().at(0) <= 57) {
                         token.reset();
                     } else {
-                        //dont add C++ key words
+                        // dont add C++ key words
                         wxString tmpName(token.getName());
-                        
-                        if (m_keywords.count(tmpName) == 0) {
-                            
+
+                        if(m_keywords.count(tmpName) == 0) {
+
                             token.setFilename(m_filename);
                             token.setLineNumber(lineNo);
-                            allTokens.push_back( token );
+                            allTokens.push_back(token);
                         }
                         token.reset();
                     }
@@ -302,47 +299,48 @@ CppToken::List_t CppWordScanner::tokenize()
 
             break;
         case STATE_PRE_PROCESSING:
-            // if the char before the \n is \ (backslash) or \r\ (CR followed by backslash) remain in pre-processing state
-            if ( accessor.match("\n", i) && (!accessor.match("\\", i-1) && !accessor.match("\\\r", i-2)) ) {
+            // if the char before the \n is \ (backslash) or \r\ (CR followed by backslash) remain in pre-processing
+            // state
+            if(accessor.match("\n", i) && (!accessor.match("\\", i - 1) && !accessor.match("\\\r", i - 2))) {
                 // no wrap
                 state = STATE_NORMAL;
 
-            } else if ( accessor.match("//", i)) {
+            } else if(accessor.match("//", i)) {
                 // C++ comment, advance i
                 state = STATE_CPP_COMMENT;
                 i++;
             }
             break;
         case STATE_C_COMMENT:
-            if ( accessor.match("*/", i)) {
+            if(accessor.match("*/", i)) {
                 state = STATE_NORMAL;
                 i++;
             }
             break;
         case STATE_CPP_COMMENT:
-            if ( accessor.match("\n", i)) {
+            if(accessor.match("\n", i)) {
                 state = STATE_NORMAL;
             }
             break;
         case STATE_DQ_STRING:
-            if (accessor.match("\\\"", i)) {
-                //escaped string
+            if(accessor.match("\\\"", i)) {
+                // escaped string
                 i++;
             } else if(accessor.match("\\", i)) {
                 i++;
-            } else if (accessor.match("\"", i)) {
+            } else if(accessor.match("\"", i)) {
                 state = STATE_NORMAL;
             }
             break;
         case STATE_SINGLE_STRING:
-            if (accessor.match("\\'", i)) {
-                //escaped single string
+            if(accessor.match("\\'", i)) {
+                // escaped single string
                 i++;
 
             } else if(accessor.match("\\", i)) {
                 i++;
 
-            } else if (accessor.match("'", i)) {
+            } else if(accessor.match("'", i)) {
                 state = STATE_NORMAL;
             }
             break;
@@ -353,21 +351,12 @@ CppToken::List_t CppWordScanner::tokenize()
 
 void CppWordScanner::doInit()
 {
-    wxString key_words =
-        wxT("auto break case char const continue default define defined do double elif else endif enum error extern float")
-        wxT("for  goto if ifdef ifndef include int long pragma register return short signed sizeof static struct switch")
-        wxT("typedef undef union unsigned void volatile while class namespace delete friend inline new operator overload")
-        wxT("protected private public this virtual template typename dynamic_cast static_cast const_cast reinterpret_cast")
-        wxT("using throw catch size_t");
-
-    //add this items into map
-    wxArrayString tmpArr = ::wxStringTokenize(key_words, " ");
-    m_keywords.insert(tmpArr.begin(), tmpArr.end());
+    TagsManager::GetCXXKeywords(m_keywords);
 }
 
 TextStatesPtr CppWordScanner::states()
 {
-    TextStatesPtr bitmap (new TextStates());
+    TextStatesPtr bitmap(new TextStates());
     bitmap->states.resize(m_text.size());
 
     if(bitmap->states.size() == 0) {
@@ -381,63 +370,64 @@ TextStatesPtr CppWordScanner::states()
     int lineNo(0);
 
     StringAccessor accessor(m_text);
-    for (size_t i=0; i<m_text.size(); i++) {
+    for(size_t i = 0; i < m_text.size(); i++) {
 
         // Keep track of line numbers
-        if(accessor.match("\n", i) && (state == STATE_NORMAL || state == STATE_PRE_PROCESSING || state == STATE_CPP_COMMENT || state == STATE_C_COMMENT)) {
+        if(accessor.match("\n", i) && (state == STATE_NORMAL || state == STATE_PRE_PROCESSING ||
+                                       state == STATE_CPP_COMMENT || state == STATE_C_COMMENT)) {
             lineNo++;
         }
 
-        switch (state) {
+        switch(state) {
 
         case STATE_NORMAL:
-            if (accessor.match("#", i)) {
+            if(accessor.match("#", i)) {
 
-                if ( i == 0 ||                    // satrt of document
-                     accessor.match("\n", i-1)) { // we are at start of line
+                if(i == 0 ||                      // satrt of document
+                   accessor.match("\n", i - 1)) { // we are at start of line
                     state = STATE_PRE_PROCESSING;
                 }
 
-            } else if (accessor.match("//", i)) {
+            } else if(accessor.match("//", i)) {
 
                 // C++ comment, advance i
                 state = STATE_CPP_COMMENT;
                 bitmap->SetState(i, STATE_CPP_COMMENT, depth, lineNo);
                 i++;
 
-            } else if (accessor.match("/*", i)) {
+            } else if(accessor.match("/*", i)) {
 
                 // C comment
                 state = STATE_C_COMMENT;
                 bitmap->SetState(i, STATE_C_COMMENT, depth, lineNo);
                 i++;
 
-            } else if (accessor.match("'", i)) {
+            } else if(accessor.match("'", i)) {
 
                 // single quoted string
                 state = STATE_SINGLE_STRING;
 
-            } else if (accessor.match("\"", i)) {
+            } else if(accessor.match("\"", i)) {
 
                 // dbouble quoted string
                 state = STATE_DQ_STRING;
 
-            } else if (accessor.match("{", i)) {
+            } else if(accessor.match("{", i)) {
                 depth++;
 
-            } else if (accessor.match("}", i)) {
+            } else if(accessor.match("}", i)) {
                 depth--;
-
             }
 
             break;
         case STATE_PRE_PROCESSING:
-            // if the char before the \n is \ (backslash) or \r\ (CR followed by backslash) remain in pre-processing state
-            if ( accessor.match("\n", i) && (!accessor.match("\\", i-1) && !accessor.match("\\\r", i-2)) ) {
+            // if the char before the \n is \ (backslash) or \r\ (CR followed by backslash) remain in pre-processing
+            // state
+            if(accessor.match("\n", i) && (!accessor.match("\\", i - 1) && !accessor.match("\\\r", i - 2))) {
                 // no wrap
                 state = STATE_NORMAL;
 
-            } else if ( accessor.match("//", i)) {
+            } else if(accessor.match("//", i)) {
                 // C++ comment, advance i
                 state = STATE_CPP_COMMENT;
                 bitmap->SetState(i, STATE_CPP_COMMENT, depth, lineNo);
@@ -445,20 +435,20 @@ TextStatesPtr CppWordScanner::states()
             }
             break;
         case STATE_C_COMMENT:
-            if ( accessor.match("*/", i)) {
+            if(accessor.match("*/", i)) {
                 bitmap->SetState(i, state, depth, lineNo);
                 state = STATE_NORMAL;
                 i++;
             }
             break;
         case STATE_CPP_COMMENT:
-            if ( accessor.match("\n", i)) {
+            if(accessor.match("\n", i)) {
                 state = STATE_NORMAL;
             }
             break;
         case STATE_DQ_STRING:
-            if (accessor.match("\\\"", i)) {
-                //escaped string
+            if(accessor.match("\\\"", i)) {
+                // escaped string
                 bitmap->SetState(i, STATE_DQ_STRING, depth, lineNo);
                 i++;
 
@@ -466,20 +456,20 @@ TextStatesPtr CppWordScanner::states()
                 bitmap->SetState(i, STATE_DQ_STRING, depth, lineNo);
                 i++;
 
-            } else if (accessor.match("\"", i)) {
+            } else if(accessor.match("\"", i)) {
                 state = STATE_NORMAL;
             }
             break;
         case STATE_SINGLE_STRING:
-            if (accessor.match("\\'", i)) {
-                //escaped single string
+            if(accessor.match("\\'", i)) {
+                // escaped single string
                 bitmap->SetState(i, STATE_SINGLE_STRING, depth, lineNo);
                 i++;
             } else if(accessor.match("\\", i)) {
                 bitmap->SetState(i, STATE_SINGLE_STRING, depth, lineNo);
                 i++;
 
-            } else if (accessor.match("'", i)) {
+            } else if(accessor.match("'", i)) {
                 state = STATE_NORMAL;
             }
             break;
@@ -492,14 +482,11 @@ TextStatesPtr CppWordScanner::states()
 int TextStates::FunctionEndPos(int position)
 {
     // Sanity
-    if(text.length() != states.size())
-        return wxNOT_FOUND;
+    if(text.length() != states.size()) return wxNOT_FOUND;
 
-    if(position < 0)
-        return wxNOT_FOUND;
+    if(position < 0) return wxNOT_FOUND;
 
-    if(position >= (int)text.length())
-        return wxNOT_FOUND;
+    if(position >= (int)text.length()) return wxNOT_FOUND;
 
     if(states[position].depth < 0) {
         // we are already at depth 0 (which means global scope)
@@ -513,9 +500,8 @@ int TextStates::FunctionEndPos(int position)
     SetPosition(position);
 
     wxChar ch = Next();
-    while ( ch ) {
-        if(states[pos].depth == curdepth + 1)
-            break;
+    while(ch) {
+        if(states[pos].depth == curdepth + 1) break;
         ch = Next();
     }
 
@@ -523,9 +509,8 @@ int TextStates::FunctionEndPos(int position)
     // but this time break when depth is curdepth
 
     ch = Next();
-    while ( ch ) {
-        if(states[pos].depth == curdepth)
-            break;
+    while(ch) {
+        if(states[pos].depth == curdepth) break;
         ch = Next();
     }
 
@@ -538,19 +523,17 @@ int TextStates::FunctionEndPos(int position)
 
 wxChar TextStates::Next()
 {
-    if(text.length() != states.size())
-        return 0;
+    if(text.length() != states.size()) return 0;
 
-    if(pos == wxNOT_FOUND)
-        return 0;
+    if(pos == wxNOT_FOUND) return 0;
 
     // reached end of text
     pos++;
-    while( pos < (int)text.length() ) {
+    while(pos < (int)text.length()) {
         int st = states[pos].state;
         if(st == CppWordScanner::STATE_NORMAL) {
-            if(text.length() > (size_t)pos)
-                return text.at(pos);;
+            if(text.length() > (size_t)pos) return text.at(pos);
+            ;
             return 0;
         }
         pos++;
@@ -560,22 +543,18 @@ wxChar TextStates::Next()
 
 wxChar TextStates::Previous()
 {
-    if(text.length() != states.size())
-        return 0;
+    if(text.length() != states.size()) return 0;
 
-    if(pos == wxNOT_FOUND)
-        return 0;
+    if(pos == wxNOT_FOUND) return 0;
 
     // reached start of text
-    if(pos == 0)
-        return 0;
+    if(pos == 0) return 0;
 
     pos--;
-    while( pos ) {
+    while(pos) {
         int st = states[pos].state;
         if(st == CppWordScanner::STATE_NORMAL) {
-            if(text.length() > (size_t)pos)
-                return text.at(pos);
+            if(text.length() > (size_t)pos) return text.at(pos);
             return 0;
         }
         pos--;
@@ -583,31 +562,26 @@ wxChar TextStates::Previous()
     return 0;
 }
 
-void TextStates::SetPosition(int pos)
-{
-    this->pos = pos;
-}
+void TextStates::SetPosition(int pos) { this->pos = pos; }
 
 void TextStates::SetState(size_t where, int state, int depth, int lineNo)
 {
     if(where < states.size()) {
-        states[where].depth   = depth;
-        states[where].state   = state;
-        states[where].lineNo  = lineNo;
+        states[where].depth = depth;
+        states[where].state = state;
+        states[where].lineNo = lineNo;
     }
 
     if(lineToPos.empty() || (int)lineToPos.size() - 1 < lineNo) {
-        lineToPos.push_back( where );
+        lineToPos.push_back(where);
     }
 }
 
 int TextStates::LineToPos(int lineNo)
 {
-    if(IsOk() == false)
-        return wxNOT_FOUND;
+    if(IsOk() == false) return wxNOT_FOUND;
 
-    if(lineToPos.empty() || (int)lineToPos.size() < lineNo || lineNo < 0)
-        return wxNOT_FOUND;
+    if(lineToPos.empty() || (int)lineToPos.size() < lineNo || lineNo < 0) return wxNOT_FOUND;
 
     return lineToPos.at(lineNo);
 }
