@@ -44,7 +44,8 @@ void FileExtManager::Init()
         m_map[wxT("cpp")] = TypeSourceCpp;
         m_map[wxT("cxx")] = TypeSourceCpp;
         m_map[wxT("c++")] = TypeSourceCpp;
-        m_map[wxT("as")] = TypeSourceCpp; // AngelScript files are handled as C++ source files in CodeLite
+        m_map[wxT("as")] = TypeSourceCpp;  // AngelScript files are handled as C++ source files in CodeLite
+        m_map[wxT("ino")] = TypeSourceCpp; // Arduino sketches
         m_map[wxT("c")] = TypeSourceC;
 
         m_map[wxT("h")] = TypeHeader;
@@ -73,10 +74,12 @@ void FileExtManager::Init()
         m_map[wxT("php5")] = TypePhp;
         m_map[wxT("inc")] = TypePhp;
         m_map[wxT("phtml")] = TypePhp;
+        m_map[wxT("ctp")] = TypePhp;
 
         m_map[wxT("xml")] = TypeXml;
         m_map[wxT("xrc")] = TypeXRC;
         m_map[wxT("css")] = TypeCSS;
+        m_map[wxT("less")] = TypeCSS;
         m_map[wxT("js")] = TypeJS;
         m_map[wxT("javascript")] = TypeJS;
         m_map[wxT("py")] = TypePython;
@@ -213,30 +216,6 @@ bool FileExtManager::IsCxxFile(const wxString& filename)
     return ft == TypeSourceC || ft == TypeSourceCpp || ft == TypeHeader;
 }
 
-bool FileExtManager::IsJavascriptFile(const wxString& filename)
-{
-    FileType ft = GetType(filename);
-    if(ft == TypeOther) {
-        // failed to detect the type
-        if(!AutoDetectByContent(filename, ft)) {
-            return false;
-        }
-    }
-    return ft == TypeJS;
-}
-
-bool FileExtManager::IsPHPFile(const wxString& filename)
-{
-    FileType ft = GetType(filename);
-    if(ft == TypeOther) {
-        // failed to detect the type
-        if(!AutoDetectByContent(filename, ft)) {
-            return false;
-        }
-    }
-    return ft == TypePhp;
-}
-
 bool FileExtManager::AutoDetectByContent(const wxString& filename, FileExtManager::FileType& fileType)
 {
     wxString fileContent;
@@ -256,7 +235,7 @@ bool FileExtManager::AutoDetectByContent(const wxString& filename, FileExtManage
     return false;
 }
 
-bool FileExtManager::IsJavaFile(const wxString& filename)
+bool FileExtManager::IsFileType(const wxString& filename, FileExtManager::FileType type)
 {
     FileType ft = GetType(filename);
     if(ft == TypeOther) {
@@ -265,5 +244,11 @@ bool FileExtManager::IsJavaFile(const wxString& filename)
             return false;
         }
     }
-    return ft == TypeJava;
+    return (ft == type);
 }
+
+bool FileExtManager::IsJavascriptFile(const wxString& filename) { return FileExtManager::IsFileType(filename, TypeJS); }
+
+bool FileExtManager::IsPHPFile(const wxString& filename) { return FileExtManager::IsFileType(filename, TypePhp); }
+
+bool FileExtManager::IsJavaFile(const wxString& filename) { return FileExtManager::IsFileType(filename, TypeJava); }
