@@ -39,6 +39,7 @@
 #include <set>
 #include "cl_command_event.h"
 #include <tags_options_data.h>
+#include "CxxVariableScanner.h"
 
 #define DEBUG_MESSAGE(x) CL_DEBUG1(x.c_str())
 
@@ -77,9 +78,7 @@ ParseThread::ParseThread()
 {
 }
 
-ParseThread::~ParseThread()
-{
-}
+ParseThread::~ParseThread() {}
 
 void ParseThread::ProcessRequest(ThreadRequest* request)
 {
@@ -211,9 +210,10 @@ void ParseThread::ProcessSimple(ParseRequest* req)
     wxString dbfile = req->getDbfile();
     wxString file = req->getFile();
 
+    clDEBUG1() << "Parsing saved file:" << file << clEndl;
     // Skip binary file
     if(TagsManagerST::Get()->IsBinaryFile(file)) {
-        DEBUG_MESSAGE(wxString::Format(wxT("Skipping binary file %s"), file.c_str()));
+        clDEBUG1() << "File:" << file << "is binady and will be skipped" << clEndl;
         return;
     }
 
@@ -227,6 +227,8 @@ void ParseThread::ProcessSimple(ParseRequest* req)
     wxString file_name(req->getFile());
     tagmgr->SourceToTags(file_name, tags);
 
+    clDEBUG1() << "Parsed file output: [" << tags << "]" << clEndl;
+
     int count;
     DoStoreTags(tags, file_name, count, db);
 
@@ -307,8 +309,8 @@ void ParseThread::GetFileListToParse(const wxString& filename, wxArrayString& ar
     }
 }
 
-void
-ParseThread::ParseAndStoreFiles(ParseRequest* req, const wxArrayString& arrFiles, int initalCount, ITagsStoragePtr db)
+void ParseThread::ParseAndStoreFiles(
+    ParseRequest* req, const wxArrayString& arrFiles, int initalCount, ITagsStoragePtr db)
 {
     // Loop over the files and parse them
     int totalSymbols(0);
@@ -450,7 +452,7 @@ void ParseThread::ProcessParseAndStore(ParseRequest* req)
     }
 
     // Process the macros
-    //PPTable::Instance()->Squeeze();
+    // PPTable::Instance()->Squeeze();
     const std::map<wxString, PPToken>& table = PPTable::Instance()->GetTable();
 
     // Store the macros
@@ -526,15 +528,9 @@ void ParseThread::FindIncludedFiles(ParseRequest* req, std::set<wxString>* newSe
 //--------------------------------------------------------------------------------------
 // Parse Request Class
 //--------------------------------------------------------------------------------------
-void ParseRequest::setDbFile(const wxString& dbfile)
-{
-    _dbfile = dbfile.c_str();
-}
+void ParseRequest::setDbFile(const wxString& dbfile) { _dbfile = dbfile.c_str(); }
 
-void ParseRequest::setTags(const wxString& tags)
-{
-    _tags = tags.c_str();
-}
+void ParseRequest::setTags(const wxString& tags) { _tags = tags.c_str(); }
 
 ParseRequest::ParseRequest(const ParseRequest& rhs)
 {
@@ -553,14 +549,9 @@ ParseRequest& ParseRequest::operator=(const ParseRequest& rhs)
     return *this;
 }
 
-void ParseRequest::setFile(const wxString& file)
-{
-    _file = file.c_str();
-}
+void ParseRequest::setFile(const wxString& file) { _file = file.c_str(); }
 
-ParseRequest::~ParseRequest()
-{
-}
+ParseRequest::~ParseRequest() {}
 
 // Adaptor to the parse thread
 static ParseThread* gs_theParseThread = NULL;
@@ -646,6 +637,7 @@ void ParseThread::ProcessColourRequest(ParseRequest* req)
     // read the file content
     wxFFile fp(req->getFile(), "rb");
     if(fp.IsOpened()) {
+        wxString flatStrLocals, flatClasses;
         wxString content;
         fp.ReadAll(&content);
         fp.Close();
@@ -693,8 +685,31 @@ void ParseThread::ProcessColourRequest(ParseRequest* req)
 
         db->RemoveNonWorkspaceSymbols(tokensArr, kinds);
 
+        // Now, get the locals
+        {
+            CxxVariableScanner scanner(content);
+            CxxVariable::List_t vars = scanner.GetVariables();
+
+            std::for_each(vars.begin(), vars.end(), [&](CxxVariable::Ptr_t var) {
+                if(var->IsUsing()) {
+                    tokensArr.Add(var->GetName());
+                } else {
+                    flatStrLocals << var->GetName() << " ";
+                }
+            });
+        }
+
+        // Convert the class types into a flat string
+        tokensArr.Sort();
+
+        // Convert the output to a space delimited array
+        std::for_each(tokensArr.begin(), tokensArr.end(), [&](const wxString& token) { flatClasses << token << " "; });
+
         if(req->_evtHandler) {
             clCommandEvent event(wxEVT_PARSE_THREAD_SUGGEST_COLOUR_TOKENS);
+            tokensArr.clear();
+            tokensArr.Add(flatClasses);
+            tokensArr.Add(flatStrLocals);
             event.SetStrings(tokensArr);
             event.SetFileName(req->getFile());
             req->_evtHandler->AddPendingEvent(event);
