@@ -28,9 +28,9 @@ int main()
     //testPureLexer( buf );
     //print the scope name
     //testScopeParser(buf);
-    //testVarParser(buf);
+    testVarParser(buf);
     //testExprParser(buf);
-    testFuncParser(buf);
+    //testFuncParser(buf);
     //testTypedefParser(buf);
     //testIsPrimitive(buf);
     //testFuncParser(buf);
