@@ -39,6 +39,7 @@
 #include "wx/tokenzr.h"
 #include <algorithm>
 #include "file_logger.h"
+#include "globals.h"
 
 #ifdef __WXMSW__
 #include "windows.h"
@@ -50,13 +51,22 @@ DBG_BREAK_PROC_FUNC_PTR DebugBreakProcessFunc = NULL;
 HINSTANCE Kernel32Dll = NULL;
 
 // define a dummy control handler
-BOOL CtrlHandler(DWORD fdwCtrlType)
+static BOOL CtrlHandler(DWORD fdwCtrlType)
 {
     wxUnusedVar(fdwCtrlType);
 
     // return FALSE so other process in our group are allowed to process this event
     return FALSE;
 }
+
+static BOOL SigHandler(DWORD CtrlType)
+{
+    if(CtrlType == CTRL_C_EVENT) {
+        return TRUE;
+    }
+    return FALSE;
+}
+
 #endif
 
 #include <sys/types.h>
@@ -238,26 +248,29 @@ bool DbgGdb::Start(const DebugSessionInfo& si)
     m_observer->UpdateAddLine(wxString::Format(wxT("Current working dir: %s"), wxGetCwd().c_str()));
     m_observer->UpdateAddLine(wxString::Format(wxT("Launching gdb from : %s"), si.cwd.c_str()));
     m_observer->UpdateAddLine(wxString::Format(wxT("Starting debugger  : %s"), cmd.c_str()));
+
 #ifdef __WXMSW__
     // When using remote debugging on Windows we need a console window, as this is the only
     // mechanism to send a Ctrl-C event and signal a SIGINT to interrupt the target.
-    bool needs_console = GetIsRemoteDebugging() | m_info.showTerminal;
+    bool needs_console = GetIsRemoteDebugging() || m_info.showTerminal;
 #else
     bool needs_console = m_info.showTerminal;
 #endif
-    m_gdbProcess = CreateAsyncProcess(this,
-                                      cmd,
-                                      // show console?
-                                      needs_console ? IProcessCreateConsole : IProcessCreateDefault,
-                                      si.cwd);
+
+    size_t flags = needs_console ? IProcessCreateConsole : IProcessCreateDefault;
+    if(m_info.flags & DebuggerInformation::kRunAsSuperuser) {
+        flags |= IProcessCreateAsSuperuser;
+    }
+
+    m_gdbProcess = CreateAsyncProcess(this, cmd, flags, si.cwd);
     if(!m_gdbProcess) {
         return false;
     }
+
 #ifdef __WXMSW__
     if(GetIsRemoteDebugging()) {
         // This doesn't really make sense, but AttachConsole fails without it...
-        AllocConsole();
-        FreeConsole(); // Disconnect any existing console window.
+        wxMilliSleep(1000);
 
         if(!AttachConsole(m_gdbProcess->GetPid()))
             m_observer->UpdateAddLine(wxString::Format(wxT("AttachConsole returned error %d"), GetLastError()));
@@ -266,7 +279,7 @@ bool DbgGdb::Start(const DebugSessionInfo& si)
         if(!m_info.showTerminal) SetWindowPos(GetConsoleWindow(), HWND_BOTTOM, 0, 0, 0, 0, SWP_HIDEWINDOW);
 
         // Finally we ignore SIGINT so we don't get killed by our own signal
-        signal(SIGINT, SIG_IGN);
+        SetConsoleCtrlHandler((PHANDLER_ROUTINE)SigHandler, TRUE);
     }
 #endif
     m_gdbProcess->SetHardKill(true);
@@ -318,6 +331,13 @@ bool DbgGdb::Run(const wxString& args, const wxString& comm)
 
 void DbgGdb::DoCleanup()
 {
+#ifdef __WXMSW__
+    if(GetIsRemoteDebugging()) {
+        SetConsoleCtrlHandler((PHANDLER_ROUTINE)SigHandler, FALSE);
+        FreeConsole(); // Disconnect any existing console window.
+    }
+#endif
+
     wxDELETE(m_gdbProcess);
     SetIsRecording(false);
     m_reverseDebugging = false;
@@ -343,8 +363,7 @@ bool DbgGdb::Stop()
     m_goingDown = true;
 
     if(!m_attachedMode) {
-
-        wxKill(m_debuggeePid, wxSIGKILL, NULL, wxKILL_CHILDREN);
+        clKill((int)m_debuggeePid, wxSIGKILL, true, (m_info.flags & DebuggerInformation::kRunAsSuperuser));
     }
 
     wxCommandEvent event(wxEVT_GDB_STOP_DEBUGGER);
@@ -380,7 +399,6 @@ bool DbgGdb::Break(const BreakpointInfo& bp)
 
     // by default, use full paths for the file name when setting breakpoints
     wxString tmpfileName(fn.GetFullPath());
-    ;
     if(m_info.useRelativeFilePaths) {
         // user set the option to use relative paths (file name w/o the full path)
         tmpfileName = fn.GetFullName();
@@ -445,7 +463,8 @@ bool DbgGdb::Break(const BreakpointInfo& bp)
     } else if(bp.bp_type != BP_type_watchpt) {
         // Function and Lineno locations can/should be prepended by a filename (but see later)
         if(!tmpfileName.IsEmpty() && bp.lineno > 0) {
-            breakWhere << wxT("\"\\\"") << tmpfileName << wxT(":") << bp.lineno << wxT("\\\"\"");
+            breakWhere << tmpfileName << wxT(":") << bp.lineno;
+            breakWhere.Prepend("\"").Append("\"");
         } else if(!bp.function_name.IsEmpty()) {
             if(bp.regex) {
                 // update the command
@@ -564,7 +583,9 @@ bool DbgGdb::Interrupt()
         // debuggee process
         return false;
 #else
-        kill(m_debuggeePid, SIGINT);
+        // Send SIGINT to the process to interrupt it
+        clKill((int)m_debuggeePid, wxSIGINT, false, (m_info.flags & DebuggerInformation::kRunAsSuperuser));
+        // kill(m_debuggeePid, SIGINT);
         return true;
 #endif
     } else {
@@ -626,7 +647,7 @@ bool DbgGdb::FilterMessage(const wxString& msg)
     }
 
     if(tmpmsg.Contains(wxT("mi_cmd_var_create: unable to create variable object")) ||
-       msg.Contains(wxT("mi_cmd_var_create: unable to create variable object"))) {
+        msg.Contains(wxT("mi_cmd_var_create: unable to create variable object"))) {
         return true;
     }
 
@@ -635,7 +656,7 @@ bool DbgGdb::FilterMessage(const wxString& msg)
     }
 
     if(tmpmsg.Contains(wxT("No symbol \"this\" in current context")) ||
-       msg.Contains(wxT("No symbol \"this\" in current context"))) {
+        msg.Contains(wxT("No symbol \"this\" in current context"))) {
         return true;
     }
 
@@ -1047,6 +1068,10 @@ bool DbgGdb::DoInitializeGdb(const DebugSessionInfo& sessionInfo)
     }
 #endif
 
+    if(!(m_info.flags & DebuggerInformation::kPrintObjectOff)) {
+        ExecuteCmd("set print object on");
+    }
+
     ExecuteCmd(wxT("set width 0"));
     ExecuteCmd(wxT("set height 0"));
 
@@ -1270,7 +1295,6 @@ bool DbgGdb::UpdateWatch(const wxString& name)
     wxString cmd;
     cmd << wxT("-var-update \"") << name << wxT("\" ");
     return WriteCommand(cmd, new DbgVarObjUpdate(m_observer, this, name, DBG_USERR_WATCHTABLE));
-    return true;
 }
 
 void DbgGdb::AssignValue(const wxString& expression, const wxString& newValue)
@@ -1365,7 +1389,7 @@ bool DbgGdb::Disassemble(const wxString& filename, int lineNumber)
     if(/*filename.IsEmpty() || lineNumber == wxNOT_FOUND*/ true) {
         // Use the $pc
         if(!WriteCommand("-data-disassemble -s \"$pc -100\" -e \"$pc + 100\" -- 0",
-                         new DbgCmdHandlerDisasseble(m_observer, this)))
+               new DbgCmdHandlerDisasseble(m_observer, this)))
             return false;
 
     } else {
@@ -1374,13 +1398,13 @@ bool DbgGdb::Disassemble(const wxString& filename, int lineNumber)
         tmpfile.Replace("\\", "/"); // gdb does not like backslashes...
 
         if(!WriteCommand(wxString() << "-data-disassemble -f \"" << tmpfile << "\" -l " << lineNumber << " -n -1 -- 0",
-                         new DbgCmdHandlerDisasseble(m_observer, this)))
+               new DbgCmdHandlerDisasseble(m_observer, this)))
             return false;
     }
 
     // get the current instruction
-    if(!WriteCommand("-data-disassemble -s \"$pc\" -e \"$pc + 1\" -- 0",
-                     new DbgCmdHandlerDisassebleCurLine(m_observer, this)))
+    if(!WriteCommand(
+           "-data-disassemble -s \"$pc\" -e \"$pc + 1\" -- 0", new DbgCmdHandlerDisassebleCurLine(m_observer, this)))
         return false;
 
     return true;
@@ -1420,8 +1444,13 @@ bool DbgGdb::Attach(const DebugSessionInfo& si)
     m_observer->UpdateAddLine(wxString::Format(wxT("Current working dir: %s"), wxGetCwd().c_str()));
     m_observer->UpdateAddLine(wxString::Format(wxT("Launching gdb from : %s"), wxGetCwd().c_str()));
     m_observer->UpdateAddLine(wxString::Format(wxT("Starting debugger  : %s"), cmd.c_str()));
-
-    m_gdbProcess = CreateAsyncProcess(this, cmd);
+    
+    // Build the process creation flags
+    size_t createFlags = IProcessCreateDefault;
+    if(m_info.flags & DebuggerInformation::kRunAsSuperuser) {
+        createFlags |= IProcessCreateAsSuperuser;
+    }
+    m_gdbProcess = CreateAsyncProcess(this, cmd, createFlags);
     if(!m_gdbProcess) {
         return false;
     }
@@ -1445,7 +1474,7 @@ void DbgGdb::EnableRecording(bool b)
         WriteCommand("target record-full", new DbgCmdRecordHandler(m_observer, this));
     } else {
         WriteCommand("record stop", NULL);
-        
+
         // If recording is OFF, disable the reverse-debugging switch
         SetIsRecording(false);
         m_reverseDebugging = false;
