@@ -1,8 +1,8 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
-// file name            : gdb_result_parser.h
+// Copyright            : (C) 2015 Eran Ifrah
+// File name            : gdb_result_parser.h
 //
 // -------------------------------------------------------------------------
 // A
@@ -73,3 +73,4 @@
 #define GDB_ASM_INSTS 304
 #define GDB_THREAD_GROUPS 305
 #define GDB_REGISTER_NAMES 306
+#define GDB_DYNAMIC 307
