@@ -47,10 +47,12 @@
 #include <wx/msgdlg.h>
 #include "ExternalToolsProcessManager.h"
 #include "ExternalToolsManager.h"
+#include "codelite_events.h"
 
 static ExternalToolsPlugin* thePlugin = NULL;
 
-struct DecSort {
+struct DecSort
+{
     bool operator()(const ToolInfo& t1, const ToolInfo& t2) { return t1.GetName().CmpNoCase(t2.GetName()) > 0; }
 };
 
@@ -104,6 +106,9 @@ ExternalToolsPlugin::ExternalToolsPlugin(IManager* manager)
             wxString::Format("Ctrl-Shift-%d", i),
             wxString::Format("Plugins::External Tools::External Tool %d", i));
     }
+
+    // Bind the "OnFileSave" event
+    EventNotifier::Get()->Bind(wxEVT_FILE_SAVED, &ExternalToolsPlugin::OnFileSave, this);
 }
 
 ExternalToolsPlugin::~ExternalToolsPlugin() {}
@@ -182,6 +187,7 @@ void ExternalToolsPlugin::HookPopupMenu(wxMenu* menu, MenuType type)
 
 void ExternalToolsPlugin::UnPlug()
 {
+    EventNotifier::Get()->Unbind(wxEVT_FILE_SAVED, &ExternalToolsPlugin::OnFileSave, this);
     topWin->Unbind(wxEVT_MENU, &ExternalToolsPlugin::OnSettings, this, XRCID("external_tools_settings"));
     topWin->Unbind(wxEVT_MENU, &ExternalToolsPlugin::OnShowRunningTools, this, XRCID("external_tools_monitor"));
 
@@ -236,9 +242,11 @@ void ExternalToolsPlugin::OnLaunchExternalTool(wxCommandEvent& e)
 void ExternalToolsPlugin::DoRecreateToolbar()
 {
     if(m_mgr->AllowToolbar()) {
+        wxAuiPaneInfo pi;
         wxWindow* parent(NULL);
         if(m_tb) {
             // we have a toolbar, remove it from the docking manager
+            pi = m_mgr->GetDockingManager()->GetPane(m_tb);
             m_mgr->GetDockingManager()->DetachPane(m_tb);
             parent = m_tb->GetParent();
             m_tb->Destroy();
@@ -248,14 +256,16 @@ void ExternalToolsPlugin::DoRecreateToolbar()
 
         m_tb = CreateToolBar(parent);
         if(m_tb) {
-            m_mgr->GetDockingManager()->AddPane(m_tb,
-                                                wxAuiPaneInfo()
-                                                    .Name(GetShortName())
-                                                    .LeftDockable(true)
-                                                    .RightDockable(true)
-                                                    .Caption(GetShortName())
-                                                    .ToolbarPane()
-                                                    .Top());
+            wxAuiPaneInfo newPi;
+            // Default
+            newPi.ToolbarPane().LeftDockable().RightDockable().Caption(GetShortName()).Name(GetShortName());
+            // If we got an old toolbar, reuse its docking attributes
+            if(pi.IsOk()) {
+                newPi.Direction(pi.dock_direction).Position(pi.dock_pos).Row(pi.dock_row);
+            } else {
+                newPi.Top().Position(999).Row(0);
+            }
+            m_mgr->GetDockingManager()->AddPane(m_tb, newPi);
 
             // Apply changes
             m_mgr->GetDockingManager()->Update();
@@ -302,3 +312,24 @@ void ExternalToolsPlugin::OnShowRunningTools(wxCommandEvent& e)
     ExternalToolsManager dlg(EventNotifier::Get()->TopFrame());
     dlg.ShowModal();
 }
+
+void ExternalToolsPlugin::OnFileSave(clCommandEvent& event)
+{
+    event.Skip(); // always skip
+
+    // Get list of tools that should be triggered when a file is being saved
+    ExternalToolsData inData;
+    m_mgr->GetConfigTool()->ReadObject(wxT("ExternalTools"), &inData);
+    const std::vector<ToolInfo>& tools = inData.GetTools();
+    std::for_each(tools.begin(), tools.end(), [&](const ToolInfo& tool) {
+        if(tool.IsCallOnFileSave()) {
+            // Run this tool
+            ToolInfo ti = tool;
+            wxString filename = event.GetFileName();
+            ::WrapWithQuotes(filename);
+            filename += " ";
+            ti.SetArguments(filename + ti.GetArguments());
+            ToolsTaskManager::Instance()->StartTool(ti);
+        }
+    });
+}
