@@ -42,11 +42,26 @@ class ToolInfo : public SerializedObject
     wxString m_icon24;
     bool m_captureOutput;
     bool m_saveAllFiles;
+    size_t m_flags;
 
 public:
     ToolInfo();
     ~ToolInfo();
 
+    enum {
+        kCallOnFileSave = (1 << 0),
+    };
+
+protected:
+    void EnableFlag(int flag, bool b)
+    {
+        if(b) {
+            m_flags |= flag;
+        } else {
+            m_flags &= ~flag;
+        }
+    }
+
 public:
     virtual void DeSerialize(Archive& arch);
     virtual void Serialize(Archive& arch);
@@ -71,6 +86,9 @@ public:
 
     void SetSaveAllFiles(const bool& saveAllFiles) { this->m_saveAllFiles = saveAllFiles; }
     const bool& GetSaveAllFiles() const { return m_saveAllFiles; }
+
+    bool IsCallOnFileSave() const { return (m_flags & kCallOnFileSave); }
+    void SetCallOnFileSave(bool b) { EnableFlag(kCallOnFileSave, b); }
 };
 
 class ExternalToolsData : public SerializedObject
