@@ -24,8 +24,10 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "LLDBVariable.h"
+#include "json_node.h"
+#include "LLDBEnums.h"
 
-#ifndef __WXMSW__
+#if BUILD_CODELITE_LLDB
 #include <lldb/API/SBValue.h>
 #include <lldb/API/SBStream.h>
 
