@@ -121,47 +121,26 @@ wxString MacGetBasePath()
 
 ///////////////////////////////////////////////////////////////////
 
-static const wxCmdLineEntryDesc cmdLineDesc[] = {
-    { wxCMD_LINE_SWITCH, "v", "version", "Print current version", wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
+static const wxCmdLineEntryDesc cmdLineDesc[] = { { wxCMD_LINE_SWITCH, "v", "version", "Print current version",
+                                                      wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
     { wxCMD_LINE_SWITCH, "h", "help", "Print usage", wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
-    { wxCMD_LINE_SWITCH,
-      "n",
-      "no-plugins",
-      "Start codelite without any plugins",
-      wxCMD_LINE_VAL_STRING,
-      wxCMD_LINE_PARAM_OPTIONAL },
-    { wxCMD_LINE_OPTION,
-      "l",
-      "line",
-      "Open the file at a given line number",
-      wxCMD_LINE_VAL_NUMBER,
-      wxCMD_LINE_PARAM_OPTIONAL },
-    { wxCMD_LINE_OPTION,
-      "b",
-      "basedir",
-      "Use this path as the CodeLite installation path (Windows only)",
-      wxCMD_LINE_VAL_STRING,
-      wxCMD_LINE_PARAM_OPTIONAL },
-    { wxCMD_LINE_OPTION,
-      "d",
-      "datadir",
-      "Use this path as the CodeLite data path",
-      wxCMD_LINE_VAL_STRING,
-      wxCMD_LINE_PARAM_OPTIONAL },
-    { wxCMD_LINE_OPTION,
-      "p",
-      "with-plugins",
-      "Comma separated list of plugins to load",
-      wxCMD_LINE_VAL_STRING,
-      wxCMD_LINE_PARAM_OPTIONAL },
-    { wxCMD_LINE_PARAM,
-      NULL,
-      NULL,
-      "Input file",
-      wxCMD_LINE_VAL_STRING,
-      wxCMD_LINE_PARAM_MULTIPLE | wxCMD_LINE_PARAM_OPTIONAL },
-    { wxCMD_LINE_NONE }
-};
+    { wxCMD_LINE_SWITCH, "n", "no-plugins", "Start CodeLite without any plugins", wxCMD_LINE_VAL_STRING,
+        wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_OPTION, "g", "dbg", "Start CodeLite's GDB debugger to debug an executable", wxCMD_LINE_VAL_STRING,
+        wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_OPTION, "l", "line", "Open the file at a given line number", wxCMD_LINE_VAL_NUMBER,
+        wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_OPTION, "b", "basedir", "Use this path as the CodeLite installation path (Windows only)",
+        wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_OPTION, "d", "datadir", "Use this path as the CodeLite data path", wxCMD_LINE_VAL_STRING,
+        wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_OPTION, "w", "dbg-dir", "When started with --dbg, set the working directory for the debugger",
+        wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_OPTION, "p", "with-plugins", "Comma separated list of plugins to load", wxCMD_LINE_VAL_STRING,
+        wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_PARAM, NULL, NULL, "Input file", wxCMD_LINE_VAL_STRING,
+        wxCMD_LINE_PARAM_MULTIPLE | wxCMD_LINE_PARAM_OPTIONAL },
+    { wxCMD_LINE_NONE } };
 
 static void massCopy(const wxString& sourceDir, const wxString& spec, const wxString& destDir)
 {
@@ -241,9 +220,8 @@ static void WaitForDebugger(int signo)
             // Go down without launching the debugger, ask the user to do it manually
             wxMessageBox(wxString::Format(wxT("Failed to launch the debugger\nYou may still attach to codelite "
                                               "manually by typing this command in a terminal:\ngdb -p %d"),
-                                          getpid()),
-                         wxT("CodeLite Crash Handler"),
-                         wxOK | wxCENTER | wxICON_ERROR);
+                             getpid()),
+                wxT("CodeLite Crash Handler"), wxOK | wxCENTER | wxICON_ERROR);
             pause();
         }
     }
@@ -265,8 +243,10 @@ CodeLiteApp::CodeLiteApp(void)
     , m_singleInstance(NULL)
     , m_pluginLoadPolicy(PP_All)
     , m_persistencManager(NULL)
+    , m_startedInDebuggerMode(false)
 #ifdef __WXMSW__
     , m_handler(NULL)
+    , m_user32Dll(NULL)
 #endif
 {
 }
@@ -286,6 +266,10 @@ CodeLiteApp::~CodeLiteApp(void)
     wxDELETE(m_persistencManager);
 }
 
+#ifdef __WXMSW__
+typedef BOOL WINAPI (*SetProcessDPIAwareFunc)();
+#endif
+
 bool CodeLiteApp::OnInit()
 {
 #if defined(__WXMSW__) && !defined(NDEBUG)
@@ -320,18 +304,26 @@ bool CodeLiteApp::OnInit()
 #endif
 
 #ifdef __WXMSW__
+    
+    m_user32Dll = LoadLibrary(L"User32.dll");
+    if(m_user32Dll) {
+        SetProcessDPIAwareFunc pFunc = (SetProcessDPIAwareFunc)GetProcAddress(m_user32Dll, "SetProcessDPIAware");
+        if(pFunc) {
+            pFunc();
+        }
+        FreeLibrary(m_user32Dll);
+        m_user32Dll = NULL;
+    }
+    
+    
     // as described in http://jrfonseca.dyndns.org/projects/gnu-win32/software/drmingw/
     // load the exception handler dll so we will get Dr MinGW at runtime
     m_handler = LoadLibrary(wxT("exchndl.dll"));
-
+    
 // Enable this process debugging priviliges
 // EnableDebugPriv();
 #endif
 
-#ifdef USE_POSIX_LAYOUT
-    clStandardPaths::Get().IgnoreAppSubDir("bin");
-#endif
-
     // Init resources and add the PNG handler
     wxSystemOptions::SetOption(_T("msw.remap"), 0);
     wxSystemOptions::SetOption("msw.notebook.themed-background", 1);
@@ -351,11 +343,21 @@ bool CodeLiteApp::OnInit()
     wxCmdLineParser parser;
     parser.SetDesc(cmdLineDesc);
     parser.SetCmdLine(wxAppBase::argc, wxAppBase::argv);
-    if(parser.Parse() != 0) {
+    if(parser.Parse(false) != 0) {
+        PrintUsage(parser);
         return false;
     }
 
     wxString newDataDir(wxEmptyString);
+    if(parser.Found("g", &m_exeToDebug)) {
+        SetStartedInDebuggerMode(true);
+        // Check to see if the user also passed "--working-directory" switch
+        parser.Found("w", &m_debuggerWorkingDirectory);
+        for(size_t i = 0; i < parser.GetParamCount(); ++i) {
+            m_debuggerArgs << parser.GetParam(i) << " ";
+        }
+    }
+
     if(parser.Found(wxT("d"), &newDataDir)) {
         clStandardPaths::Get().SetUserDataDir(newDataDir);
     }
@@ -367,7 +369,7 @@ bool CodeLiteApp::OnInit()
 
     if(parser.Found(wxT("h"))) {
         // print usage
-        parser.Usage();
+        PrintUsage(parser);
         return false;
     }
 
@@ -381,7 +383,8 @@ bool CodeLiteApp::OnInit()
         return false;
     }
 
-    if(parser.Found(wxT("n"))) {
+    // When launching CodeLite as a debugger interface, disable the plugins
+    if(parser.Found(wxT("n")) || IsStartedInDebuggerMode()) {
         // Load codelite without plugins
         SetPluginLoadPolicy(PP_None);
     }
@@ -486,7 +489,7 @@ bool CodeLiteApp::OnInit()
 #else //__WXMSW__
     if(homeDir.IsEmpty()) { // did we got a basedir from user?
 #ifdef USE_POSIX_LAYOUT
-        homeDir = clStandardPaths::Get().GetDataDir() + wxT(INSTALL_DIR);
+        homeDir = clStandardPaths::Get().GetDataDir();
 #else
         homeDir = ::wxGetCwd();
 #endif
@@ -537,15 +540,6 @@ bool CodeLiteApp::OnInit()
     // set the CTAGS_REPLACEMENT environment variable
     wxSetEnv(wxT("CTAGS_REPLACEMENTS"), ManagerST::Get()->GetStartupDirectory() + wxT("/ctags.replacements"));
 
-    long style = wxSIMPLE_BORDER;
-#if defined(__WXMSW__) || defined(__WXGTK__)
-    style |= wxFRAME_NO_TASKBAR;
-
-#else // Mac
-    wxUnusedVar(style);
-
-#endif
-
 // read the last frame size from the configuration file
 // Initialise editor configuration files
 #ifdef __WXMSW__
@@ -569,19 +563,19 @@ bool CodeLiteApp::OnInit()
 
 #if !defined(__WXMAC__) && defined(NDEBUG)
     // Now all image handlers have been added, show splash screen; but only when using Release builds of codelite
-    GeneralInfo inf;
-    cfg->ReadObject(wxT("GeneralInfo"), &inf);
-    if(inf.GetFlags() & CL_SHOW_SPLASH) {
-        wxBitmap bitmap;
-        wxString splashName(clStandardPaths::Get().GetDataDir() + wxT("/images/splashscreen.png"));
-        if(bitmap.LoadFile(splashName, wxBITMAP_TYPE_PNG)) {
-            wxString mainTitle = CODELITE_VERSION_STRING;
-            clSplashScreen::g_splashScreen = new clSplashScreen(clSplashScreen::CreateSplashScreenBitmap(bitmap),
-                                                                wxSPLASH_CENTRE_ON_SCREEN | wxSPLASH_NO_TIMEOUT,
-                                                                -1,
-                                                                NULL,
-                                                                wxID_ANY);
-            wxYield();
+    // Also, if started as debugger interface, disable the splash screen
+    if(!IsStartedInDebuggerMode()) {
+        GeneralInfo inf;
+        cfg->ReadObject(wxT("GeneralInfo"), &inf);
+        if(inf.GetFlags() & CL_SHOW_SPLASH) {
+            wxBitmap bitmap;
+            wxString splashName(clStandardPaths::Get().GetDataDir() + wxT("/images/splashscreen.png"));
+            if(bitmap.LoadFile(splashName, wxBITMAP_TYPE_PNG)) {
+                wxString mainTitle = CODELITE_VERSION_STRING;
+                clSplashScreen::g_splashScreen = new clSplashScreen(clSplashScreen::CreateSplashScreenBitmap(bitmap),
+                    wxSPLASH_CENTRE_ON_SCREEN | wxSPLASH_NO_TIMEOUT, -1, NULL, wxID_ANY);
+                wxYield();
+            }
         }
     }
 #endif
@@ -642,7 +636,7 @@ bool CodeLiteApp::OnInit()
 
 #elif defined(__WXMSW__)
 #ifdef USE_POSIX_LAYOUT
-        wxLocale::AddCatalogLookupPathPrefix(clStandardPaths::Get().GetDataDir() + wxT("/share/locale"));
+        wxLocale::AddCatalogLookupPathPrefix(clStandardPaths::Get().GetInstallDir() + wxT("\\share\\locale"));
 #else
         wxLocale::AddCatalogLookupPathPrefix(ManagerST::Get()->GetInstallDir() + wxT("\\locale"));
 #endif
@@ -690,7 +684,7 @@ bool CodeLiteApp::OnInit()
     ColoursAndFontsManager::Get().Load();
 
     // Create the main application window
-    clMainFrame::Initialize(parser.GetParamCount() == 0);
+    clMainFrame::Initialize((parser.GetParamCount() == 0) && !IsStartedInDebuggerMode());
     m_pMainFrame = clMainFrame::Get();
     m_pMainFrame->Show(TRUE);
     SetTopWindow(m_pMainFrame);
@@ -703,17 +697,19 @@ bool CodeLiteApp::OnInit()
         lineNumber = 0;
     }
 
-    for(size_t i = 0; i < parser.GetParamCount(); i++) {
-        wxString argument = parser.GetParam(i);
+    if(!IsStartedInDebuggerMode()) {
+        for(size_t i = 0; i < parser.GetParamCount(); i++) {
+            wxString argument = parser.GetParam(i);
 
-        // convert to full path and open it
-        wxFileName fn(argument);
-        fn.MakeAbsolute(ManagerST::Get()->GetOriginalCwd());
+            // convert to full path and open it
+            wxFileName fn(argument);
+            fn.MakeAbsolute(ManagerST::Get()->GetOriginalCwd());
 
-        if(fn.GetExt() == wxT("workspace")) {
-            ManagerST::Get()->OpenWorkspace(fn.GetFullPath());
-        } else {
-            clMainFrame::Get()->GetMainBook()->OpenFile(fn.GetFullPath(), wxEmptyString, lineNumber);
+            if(fn.GetExt() == wxT("workspace")) {
+                ManagerST::Get()->OpenWorkspace(fn.GetFullPath());
+            } else {
+                clMainFrame::Get()->GetMainBook()->OpenFile(fn.GetFullPath(), wxEmptyString, lineNumber);
+            }
         }
     }
 
@@ -779,7 +775,7 @@ bool CodeLiteApp::IsSingleInstance(const wxCmdLineParser& parser)
     // check for single instance
     if(clConfig::Get().Read(kConfigSingleInstance, false)) {
         wxString name = wxString::Format(wxT("CodeLite-%s"), wxGetUserId().c_str());
-        
+
         wxString path;
 #ifndef __WXMSW__
         path = "/tmp";
@@ -907,9 +903,9 @@ void CodeLiteApp::MSWReadRegistry()
 wxString CodeLiteApp::DoFindMenuFile(const wxString& installDirectory, const wxString& requiredVersion)
 {
     wxString defaultMenuFile = installDirectory + wxFileName::GetPathSeparator() + wxT("rc") +
-                               wxFileName::GetPathSeparator() + wxT("menu.xrc");
+        wxFileName::GetPathSeparator() + wxT("menu.xrc");
     wxFileName menuFile(clStandardPaths::Get().GetUserDataDir() + wxFileName::GetPathSeparator() + wxT("rc") +
-                        wxFileName::GetPathSeparator() + wxT("menu.xrc"));
+        wxFileName::GetPathSeparator() + wxT("menu.xrc"));
     if(menuFile.FileExists()) {
         // if we find the user's file menu, check that it has the required version
         {
@@ -932,13 +928,8 @@ void CodeLiteApp::DoCopyGdbPrinters()
     wxFileName printersInstallDir;
 #ifdef __WXGTK__
     printersInstallDir = wxFileName(wxString(INSTALL_DIR, wxConvUTF8), "gdb_printers");
-#else
-#ifdef USE_POSIX_LAYOUT
-    wxString commdir(clStandardPaths::Get().GetDataDir() + wxT(INSTALL_DIR));
-    printersInstallDir = wxFileName(commdir, "gdb_printers");
 #else
     printersInstallDir = wxFileName(clStandardPaths::Get().GetDataDir(), "gdb_printers");
-#endif
 #endif
 
     // copy the files to ~/.codelite/gdb_printers
@@ -1053,3 +1044,13 @@ void CodeLiteApp::AdjustPathForMSYSIfNeeded()
     ::wxSetEnv("PATH", fixedPath);
 #endif
 }
+
+void CodeLiteApp::PrintUsage(const wxCmdLineParser& parser)
+{
+#ifdef __WXMSW__
+    parser.Usage();
+#else
+    wxString usageString = parser.GetUsageString();
+    std::cout << usageString.mb_str(wxConvUTF8).data() << std::endl;
+#endif
+}
