@@ -41,18 +41,21 @@ class myDragImage;
 
 class BreakptMgr
 {
-    BreakpointInfoVec_t m_bps;        // The vector of breakpoints
-    BreakpointInfoVec_t m_pendingBreakpointsList; // These are any breakpoints that the debugger won't (yet) accept (often because they're in a plugin)
+    BreakpointInfoVec_t m_bps;                    // The vector of breakpoints
+    BreakpointInfoVec_t m_pendingBreakpointsList; // These are any breakpoints that the debugger won't (yet) accept
+                                                  // (often because they're in a plugin)
 
-    int NextInternalID;		// Used to give each bp a unique internal ID. Start at 10k to avoid confusion with gdb's IDs
+    int NextInternalID; // Used to give each bp a unique internal ID. Start at 10k to avoid confusion with gdb's IDs
 
     myDragImage* m_dragImage;
-    bool         m_expectingControl;
+    bool m_expectingControl;
 
 protected:
     // Delete all breakpoint markers for this file, then re-mark with the currently-correct marker
     void DoRefreshFileBreakpoints(LEditor* editor);
-    void DoProvideBestBP_Type(LEditor* editor, const std::vector<BreakpointInfo>& li);	// Tells the editor which is the most appropriate bp marker to show
+    void DoProvideBestBP_Type(
+        LEditor* editor,
+        const std::vector<BreakpointInfo>& li); // Tells the editor which is the most appropriate bp marker to show
 
     // Delete all line-type breakpoint markers in all editors
     // Done before refreshing after a delete, lest it was the last bp in a file
@@ -62,12 +65,12 @@ protected:
     /**
      * Return the index of the bp with the passed id, in the vector that will normally be m_bps
      */
-    int FindBreakpointById(const int id, const std::vector<BreakpointInfo>& li);
+    int FindBreakpointById(double id, const std::vector<BreakpointInfo>& li);
 
     /**
      * Can gdb accept this alteration, or will be bp have to be replaced?
      */
-    bool CanThisBreakpointBeUpdated(const BreakpointInfo &bp1, const BreakpointInfo &bp2) const;
+    bool CanThisBreakpointBeUpdated(const BreakpointInfo& bp1, const BreakpointInfo& bp2) const;
 
     /**
      * Sets bp.bp_type to the value most appropriate to its contents
@@ -77,49 +80,42 @@ protected:
     /**
      * Ignore this bp
      */
-    bool SetBPIgnoreCount(const int bid, const int ignorecount);
+    bool SetBPIgnoreCount(double bid, const int ignorecount);
 
     /**
      * Enable or Disable this breakpoint
      */
-    bool SetBPEnabledState(const int bid, const bool enable);
+    bool SetBPEnabledState(double bid, const bool enable);
 
     /**
      * Set this breakpoint's condition to that in bp.condition
      */
-    bool SetBPConditon(const BreakpointInfo &bp);
+    bool SetBPConditon(const BreakpointInfo& bp);
 
     /**
      * Set this breakpoint's command-list to that in bp.commandlist
      */
-    bool SetBPCommands(const BreakpointInfo &bp);
+    bool SetBPCommands(const BreakpointInfo& bp);
 
     /**
      * Clear the list of breakpoints
      */
-    void Clear() {
-        m_bps.clear();
-    }
+    void Clear() { m_bps.clear(); }
 
-    bool IsDuplicate(const BreakpointInfo &bp, const std::vector<BreakpointInfo>& bpList);
+    bool IsDuplicate(const BreakpointInfo& bp, const std::vector<BreakpointInfo>& bpList);
 
     void DoRemoveDuplicateBreakpoints();
-public:
 
-    void SetExpectingControl(bool expectingControl) {
-        this->m_expectingControl = expectingControl;
-    }
-    bool GetExpectingControl() const {
-        return m_expectingControl;
-    }
-    BreakptMgr() {
+public:
+    void SetExpectingControl(bool expectingControl) { this->m_expectingControl = expectingControl; }
+    bool GetExpectingControl() const { return m_expectingControl; }
+    BreakptMgr()
+    {
         NextInternalID = FIRST_INTERNAL_ID;
         m_expectingControl = false;
     }
 
-    ~BreakptMgr() {
-        Clear();
-    }
+    ~BreakptMgr() { Clear(); }
 
     /**
      * @brief refresh the breakpoints marker for a given editor
@@ -142,7 +138,8 @@ public:
      * @brief Store list of breakpoints in the pending-breakpoints list
      * @param bps
      */
-    void SetPendingBreakpoints(const std::vector<BreakpointInfo>& bps) {
+    void SetPendingBreakpoints(const std::vector<BreakpointInfo>& bps)
+    {
         m_pendingBreakpointsList.clear();
         m_pendingBreakpointsList = bps;
     }
@@ -150,9 +147,7 @@ public:
     /**
      * @brief Returns true if there are pending breakpoints
      */
-    bool PendingBreakpointsExist() {
-        return ! m_pendingBreakpointsList.empty();
-    }
+    bool PendingBreakpointsExist() { return !m_pendingBreakpointsList.empty(); }
 
     /**
      * Send again to the debugger any breakpoints that weren't accepted by the debugger the first time
@@ -165,13 +160,17 @@ public:
      * debugger, so it must be called *before* starting the debugger
      * @param fileName
      */
-    void DeleteAllBreakpointsByFileName(const wxString &fileName);
+    void DeleteAllBreakpointsByFileName(const wxString& fileName);
 
     /**
      * Add a breakpoint to the current debugger at the given line-number/file
      * Depending on the parameters, a temporary/ignored/conditional/commandlist bp can be created
      */
-    bool AddBreakpointByLineno(const wxString& file, const int lineno, const wxString& conditions = wxT(""), bool is_temp = false, bool is_disabled = false);
+    bool AddBreakpointByLineno(const wxString& file,
+                               const int lineno,
+                               const wxString& conditions = wxT(""),
+                               bool is_temp = false,
+                               bool is_disabled = false);
 
     /**
      * Add a breakpoint using the 'Properties' dialog
@@ -184,37 +183,37 @@ public:
      * all breakpoints will be passed to the debugger
      * once started
      */
-    bool AddBreakpoint(const BreakpointInfo &bp);
+    bool AddBreakpoint(const BreakpointInfo& bp);
 
     /**
      * Delete break point by id
      */
-    bool DelBreakpoint(const int id);
+    bool DelBreakpoint(double id);
 
     /**
      * Delete break point by file and line
      */
-    int DelBreakpointByLineno(const wxString& file, const int lineno);
-    
+    bool DelBreakpointByLineno(const wxString& file, const int lineno);
+
     /**
      * @brief delete all breakpoints from a given memort address
      * @param address the memory address
      * @return number of breakpoints removed
      */
-    int DelBreakpointByAddress(const wxString &address);
-    
+    int DelBreakpointByAddress(const wxString& address);
+
     /**
      * @brief add breakpoint by memory address.
      * @param address the memory address
      * @return true of success, false otherwise
      */
-    bool AddBreakpointByAddress(const wxString &address);
+    bool AddBreakpointByAddress(const wxString& address);
     /**
      * @brief return list of allmemory breakpoints
      * @param memoryBps
      */
     void GetAllMemoryBreakpoints(BreakpointInfoVec_t& memoryBps);
-    
+
     /**
      * Summon the BreakptProperties dialog for a bp
      */
@@ -228,7 +227,7 @@ public:
     /**
      * return list of breakpoints
      */
-    void GetBreakpoints(std::vector<BreakpointInfo> &li);
+    void GetBreakpoints(std::vector<BreakpointInfo>& li);
 
     /**
      * When a breakpoint is added, the debugger_id it returns finally arrives here
@@ -239,8 +238,8 @@ public:
     /**
      * @brief return the breakpoint for a given file/line
      */
-    BreakpointInfo& GetBreakpoint(const wxString &fileName, const int lineno);
-    const BreakpointInfo& GetBreakpoint(const wxString &fileName, const int lineno) const;
+    BreakpointInfo& GetBreakpoint(const wxString& fileName, const int lineno);
+    const BreakpointInfo& GetBreakpoint(const wxString& fileName, const int lineno) const;
 
     /**
      * Returns a string containing details of any breakpoints on this line
@@ -272,9 +271,7 @@ public:
     /**
      * UpdateUI for SetAllBreakpointsEnabledState, disabled version
      */
-    bool AreThereDisabledBreakpoints() {
-        return AreThereEnabledBreakpoints(false);
-    }
+    bool AreThereDisabledBreakpoints() { return AreThereEnabledBreakpoints(false); }
 
     /**
      * remove all breakpoints
@@ -284,7 +281,7 @@ public:
     /**
      * The 'edit a breakpoint' dialog
      */
-    void EditBreakpoint(int index, bool &bpExist);
+    void EditBreakpoint(int index, bool& bpExist);
 
     /**
      * If the debugger is running but can't interact, pause it.
@@ -295,7 +292,7 @@ public:
     /**
      * Notification from the debugger that breakpoint id was just hit
      */
-    void BreakpointHit(int id);
+    void BreakpointHit(double id);
 
     /**
      * Starts 'drag'n'drop' for breakpoints
@@ -310,16 +307,12 @@ public:
     /**
      * Getter for the myDragImage pointer
      */
-    myDragImage* GetDragImage() {
-        return m_dragImage;
-    }
+    myDragImage* GetDragImage() { return m_dragImage; }
 
     /**
      * Get a unique id for a breakpoint, to use when the debugger isn't running
      */
-    int GetNextID() {
-        return ++NextInternalID;
-    }
+    int GetNextID() { return ++NextInternalID; }
 
     /**
      * Save session
@@ -332,7 +325,7 @@ public:
     void LoadSession(const SessionEntry& session);
 };
 
-class myDragImage  :  public wxDragImage, public wxEvtHandler
+class myDragImage : public wxDragImage, public wxEvtHandler
 {
     LEditor* editor;
     BreakpointInfo m_bp;
@@ -345,4 +338,4 @@ public:
     void OnMotion(wxMouseEvent& event);
     void OnEndDrag(wxMouseEvent& event);
 };
-#endif //BREAKPOINTS_MANAGER_H
+#endif // BREAKPOINTS_MANAGER_H
