@@ -47,12 +47,15 @@
 #include "cl_unredo.h"
 #include "clEditorStateLocker.h"
 #include <wx/cmndata.h>
+#include <wx/bitmap.h>
 
 #define DEBUGGER_INDICATOR 11
 #define MATCH_INDICATOR 10
 #define MARKER_WORD_HIGHLIGHT 2
 #define USER_INDICATOR 3
 #define HYPERLINK_INDICATOR 4
+#define MARKER_FIND_BAR_WORD_HIGHLIGHT 5
+#define MARKER_CONTEXT_WORD_HIGHLIGHT 6
 
 class wxRichToolTip;
 class CCBoxTipWindow;
@@ -232,6 +235,11 @@ protected:
     OptionsConfigPtr m_options;
     bool m_hasCCAnnotation;
     wxRichToolTip* m_richTooltip;
+    /// A space delimited list of all the classes in this editor
+    wxString m_keywordClasses;
+    /// A space delimited list of all the variables in this editor
+    wxString m_keywordLocals;
+    wxBitmap m_editorBitmap;
 
 public:
     static bool m_ccShowPrivateMembers;
@@ -241,12 +249,15 @@ public:
     typedef std::vector<LEditor*> Vec_t;
 
     IManager* GetManager() { return m_mgr; }
-    
+
     /**
      * @brief are the CC annotations visible?
      */
     bool IsHasCCAnnotation() const { return m_hasCCAnnotation; }
     void ClearCCAnnotations();
+
+    void SetEditorBitmap(const wxBitmap& editorBitmap) { this->m_editorBitmap = editorBitmap; }
+    const wxBitmap& GetEditorBitmap() const { return m_editorBitmap; }
     
 public:
     static FindReplaceData& GetFindReplaceData() { return m_findReplaceData; }
@@ -275,7 +286,7 @@ public:
 
     // Save content of the editor to a given file (Save As...)
     // this function prompts the user for selecting file name
-    bool SaveFileAs();
+    bool SaveFileAs(const wxString& newname = wxEmptyString, const wxString& savePath = wxEmptyString);
 
     /**
      * @brief print the editor content using the printing framework
@@ -287,6 +298,11 @@ public:
      */
     void PageSetup();
 
+    virtual const wxString& GetKeywordClasses() const { return m_keywordClasses; }
+    virtual const wxString& GetKeywordLocals() const { return m_keywordLocals; }
+    virtual void SetKeywordClasses(const wxString& keywordClasses) { this->m_keywordClasses = keywordClasses; }
+    virtual void SetKeywordLocals(const wxString& keywordLocals) { this->m_keywordLocals = keywordLocals; }
+
     /**
      * @brief split the current selection into multiple carets.
      * i.e. place a caret at the end of each line in the selection
@@ -514,12 +530,11 @@ public:
      * Toggles *all* folds within the selection, not just the outer one of each function
      */
     void ToggleAllFoldsInSelection();
-    void DoRecursivelyExpandFolds(bool expand,
-                                  int startline,
-                                  int endline); // Helper function for ToggleAllFoldsInSelection()
-                                                /**
-                                                 *  Find the topmost fold level within the selection, and toggle all selected folds of that level
-                                                 */
+    void DoRecursivelyExpandFolds(bool expand, int startline,
+        int endline); // Helper function for ToggleAllFoldsInSelection()
+                      /**
+                       *  Find the topmost fold level within the selection, and toggle all selected folds of that level
+                       */
     void ToggleTopmostFoldsInSelection();
     /**
      * Load collapsed folds from a vector
@@ -548,20 +563,23 @@ public:
      * @brief find all occurances of the selected text and select
      */
     void QuickFindAll();
-
+    
     bool FindAndSelect();
     bool FindAndSelect(const FindReplaceData& data);
     bool FindAndSelect(const wxString& pattern, const wxString& name);
-    void FindAndSelectV(const wxString& pattern,
-                        const wxString& name,
-                        int pos = 0,
-                        NavMgr* unused = NULL); // The same but returns void, so usable with CallAfter()
+    void FindAndSelectV(const wxString& pattern, const wxString& name, int pos = 0,
+        NavMgr* unused = NULL); // The same but returns void, so usable with CallAfter()
     void DoFindAndSelectV(const wxArrayString& strings, int pos); // Called with CallAfter()
 
     bool Replace();
     bool Replace(const FindReplaceData& data);
 
     void RecalcHorizontalScrollbar();
+    
+    /**
+     * Get editor options. Takes any workspace/project overrides into account
+     */
+    virtual OptionsConfigPtr GetOptions() { return m_options; }
 
     /**
      * Add marker to the current line
@@ -640,10 +658,8 @@ public:
      * Add a breakpoint at the current line & file
      * Optionally make it temporary, disabled or conditional
      */
-    void AddBreakpoint(int lineno = -1,
-                       const wxString& conditions = wxT(""),
-                       const bool is_temp = false,
-                       const bool is_disabled = false);
+    void AddBreakpoint(int lineno = -1, const wxString& conditions = wxT(""), const bool is_temp = false,
+        const bool is_disabled = false);
 
     /**
      * Delete the breakpoint at the current line & file, or lineno if from ToggleBreakpoint()
@@ -671,8 +687,8 @@ public:
     //--------------------------------
     // breakpoint visualisation
     //--------------------------------
-    virtual void
-    SetBreakpointMarker(int lineno, BreakpointType bptype, bool is_disabled, const std::vector<BreakpointInfo>& li);
+    virtual void SetBreakpointMarker(
+        int lineno, BreakpointType bptype, bool is_disabled, const std::vector<BreakpointInfo>& li);
     virtual void DelAllBreakpointMarkers();
 
     virtual void HighlightLine(int lineno);
@@ -774,7 +790,11 @@ public:
     virtual void InsertText(int pos, const wxString& text) { wxStyledTextCtrl::InsertText(pos, text); }
     virtual int GetLength() { return wxStyledTextCtrl::GetLength(); }
     virtual bool IsModified() { return wxStyledTextCtrl::GetModify(); }
-    virtual void Save() { SaveFile(); }
+    virtual bool Save() { return SaveFile(); }
+    virtual bool SaveAs(const wxString& defaultName = wxEmptyString, const wxString& savePath = wxEmptyString)
+    {
+        return SaveFileAs(defaultName, savePath);
+    }
     virtual int GetEOL() { return wxStyledTextCtrl::GetEOLMode(); }
     virtual int GetCurrentLine();
     virtual void ReplaceSelection(const wxString& text);
@@ -852,7 +872,12 @@ public:
     virtual int PositionAfterPos(int pos);
     virtual int PositionBeforePos(int pos);
     virtual int GetCharAtPos(int pos);
-
+    
+    /**
+     * @brief apply editor configuration (TAB vs SPACES, tab size, EOL mode etc)
+     */
+    virtual void ApplyEditorConfig();
+    
     /**
      * @brief return true if the current editor is detached from the mainbook
      */
@@ -873,11 +898,6 @@ public:
     //----------------------------------------------------------------------------
     //----------------------------------------------------------------------------
 
-    /**
-     * Get editor options. Takes any workspace/project overrides into account
-     */
-    OptionsConfigPtr GetOptions() { return m_options; }
-
     void SetIsVisible(const bool& isVisible) { this->m_isVisible = isVisible; }
     const bool& GetIsVisible() const { return m_isVisible; }
 
@@ -904,6 +924,10 @@ private:
     void DoWrapPrevSelectionWithChars(wxChar first, wxChar last);
     void DoUpdateOptions();
     int GetFirstSingleLineCommentPos(int from, int commentStyle);
+    /**
+     * @brief return number of whitespace characters in the beginning of the line
+     */
+    int GetNumberFirstSpacesInLine(int line);
 
     void FillBPtoMarkerArray();
     BPtoMarker GetMarkerForBreakpt(enum BreakpointType bp_type);
@@ -957,8 +981,6 @@ private:
     void OnLeftDClick(wxStyledTextEvent& event);
     void OnPopupMenuUpdateUI(wxUpdateUIEvent& event);
     void OnDbgAddWatch(wxCommandEvent& event);
-    void OnDbgRunToCursor(wxCommandEvent& event);
-    void OnDbgJumpToCursor(wxCommandEvent& event);
     void OnDbgCustomWatch(wxCommandEvent& event);
     void OnDragStart(wxStyledTextEvent& e);
     void OnDragEnd(wxStyledTextEvent& e);
