@@ -26,37 +26,43 @@
 #include "globals.h"
 #include "editorsettingsbookmarkspanel.h"
 
-EditorSettingsBookmarksPanel::EditorSettingsBookmarksPanel( wxWindow* parent )
-    : EditorSettingsBookmarksBasePanel( parent )
-    , TreeBookNode<EditorSettingsBookmarksPanel>(), m_previous(wxNOT_FOUND)
+EditorSettingsBookmarksPanel::EditorSettingsBookmarksPanel(wxWindow* parent)
+    : EditorSettingsBookmarksBasePanel(parent)
+    , TreeBookNode<EditorSettingsBookmarksPanel>()
+    , m_previous(wxNOT_FOUND)
 {
     m_highlightColor->SetColour(wxString(wxT("LIGHT BLUE")));
 
-    //get the editor's options from the disk
+    // get the editor's options from the disk
     OptionsConfigPtr options = EditorConfigST::Get()->GetOptions();
     m_displaySelection->SetValue(options->GetDisplayBookmarkMargin());
 
-    // These are localised inside m_bookMarkShape. However serialising the translated strings will break other locales...
-    const wxString UnlocalisedShapes[] = { wxTRANSLATE("Small Rectangle"), wxTRANSLATE("Rounded Rectangle"), wxTRANSLATE("Circle"), wxTRANSLATE("Small Arrow") };
-    m_stringManager.AddStrings(sizeof(UnlocalisedShapes)/sizeof(wxString), UnlocalisedShapes, options->GetBookmarkShape(), m_bookMarkShape);
+    // These are localised inside m_bookMarkShape. However serialising the translated strings will break other
+    // locales...
+    const wxString UnlocalisedShapes[] = { wxTRANSLATE("Small Rectangle"),
+                                           wxTRANSLATE("Rounded Rectangle"),
+                                           wxTRANSLATE("Circle"),
+                                           wxTRANSLATE("Small Arrow") };
+    m_stringManager.AddStrings(
+        sizeof(UnlocalisedShapes) / sizeof(wxString), UnlocalisedShapes, options->GetBookmarkShape(), m_bookMarkShape);
 
-    for (size_t n=0; n < CL_N0_OF_BOOKMARK_TYPES; ++n) {
+    for(size_t n = 0; n < CL_N0_OF_BOOKMARK_TYPES; ++n) {
         BookmarkData arr;
         wxColour col = options->GetBookmarkBgColour(n);
-        if (!col.IsOk()) {
+        if(!col.IsOk()) {
             col = options->GetBookmarkBgColour(0);
         }
         arr.bg = col;
 
         col = options->GetBookmarkFgColour(n);
-        if (!col.IsOk()) {
+        if(!col.IsOk()) {
             col = options->GetBookmarkFgColour(0);
         }
         arr.fg = col;
 
         arr.defaultLabel = m_choiceBMType->GetString(n); // Store the default  value
         arr.label = options->GetBookmarkLabel(n);
-        if (!arr.label.empty()) {
+        if(!arr.label.empty()) {
             wxCHECK_RET(n < m_choiceBMType->GetCount(), "More bookmark types than there are Choice entries");
             m_choiceBMType->SetString(n, arr.label);
         }
@@ -65,42 +71,40 @@ EditorSettingsBookmarksPanel::EditorSettingsBookmarksPanel( wxWindow* parent )
     }
     ChangeSelection(0); // Fake a change to display the standard-bookmark values
 
-    wxString val1 = EditorConfigST::Get()->GetStringValue(wxT("WordHighlightColour"));
-    if (val1.IsEmpty() == false) {
+    wxString val1 = EditorConfigST::Get()->GetString(wxT("WordHighlightColour"));
+    if(val1.IsEmpty() == false) {
         m_highlightColor->SetColour(val1);
     }
 
-    long alpha(1);
-    if (EditorConfigST::Get()->GetLongValue(wxT("WordHighlightAlpha"), alpha)) {
+    long alpha = EditorConfigST::Get()->GetInteger(wxT("WordHighlightAlpha"));
+    if(alpha != wxNOT_FOUND) {
         m_spinCtrlHighlightAlpha->SetValue(alpha);
     }
-
     m_clearHighlitWords->SetValue(options->GetClearHighlitWordsOnFind());
 }
 
-
 void EditorSettingsBookmarksPanel::Save(OptionsConfigPtr options)
 {
-    options->SetDisplayBookmarkMargin( m_displaySelection->IsChecked() );
+    options->SetDisplayBookmarkMargin(m_displaySelection->IsChecked());
 
     // Get the bookmark selection, unlocalised
     wxString bmShape = m_stringManager.GetStringSelection();
-    if (bmShape.IsEmpty()) {
+    if(bmShape.IsEmpty()) {
         bmShape = wxT("Small Arrow");
     }
-    options->SetBookmarkShape( bmShape);
+    options->SetBookmarkShape(bmShape);
 
     ChangeSelection(m_choiceBMType->GetSelection()); // Fake a change to store any altered values
 
-    for (size_t n=0; n < CL_N0_OF_BOOKMARK_TYPES; ++n) {
+    for(size_t n = 0; n < CL_N0_OF_BOOKMARK_TYPES; ++n) {
         BookmarkData& arr = m_bookmarksData.at(n);
         options->SetBookmarkBgColour(arr.bg, n);
         options->SetBookmarkFgColour(arr.fg, n);
         options->SetBookmarkLabel(arr.label, n);
     }
 
-    EditorConfigST::Get()->SaveStringValue(wxT("WordHighlightColour"), m_highlightColor->GetColour().GetAsString());
-    EditorConfigST::Get()->SaveLongValue(wxT("WordHighlightAlpha"), (long)m_spinCtrlHighlightAlpha->GetValue());
+    EditorConfigST::Get()->SetString(wxT("WordHighlightColour"), m_highlightColor->GetColour().GetAsString());
+    EditorConfigST::Get()->SetInteger(wxT("WordHighlightAlpha"), (long)m_spinCtrlHighlightAlpha->GetValue());
     options->SetClearHighlitWordsOnFind(m_clearHighlitWords->IsChecked());
 }
 
@@ -108,13 +112,13 @@ void EditorSettingsBookmarksPanel::ChangeSelection(int index)
 {
     wxCHECK_RET(index < CL_N0_OF_BOOKMARK_TYPES, "Bookmark type out of range");
 
-    if (m_previous >= 0) {
+    if(m_previous >= 0) {
         // Store the current data in case it was just altered
         BookmarkData& arr = m_bookmarksData.at(m_previous);
         arr.bg = m_backgroundColor->GetColour();
         arr.fg = m_foregroundColor->GetColour();
         arr.label = m_BookmarkLabel->GetValue();
-        if (m_BookmarkLabel->GetValue().empty()) {
+        if(m_BookmarkLabel->GetValue().empty()) {
             m_choiceBMType->SetString(m_previous, arr.defaultLabel);
         } else {
             m_choiceBMType->SetString(m_previous, arr.label);
@@ -129,8 +133,4 @@ void EditorSettingsBookmarksPanel::ChangeSelection(int index)
     m_previous = index;
 }
 
-void EditorSettingsBookmarksPanel::OnBookmarkChanged(wxCommandEvent& event)
-{
-    ChangeSelection(event.GetSelection());
-}
-
+void EditorSettingsBookmarksPanel::OnBookmarkChanged(wxCommandEvent& event) { ChangeSelection(event.GetSelection()); }
