@@ -33,6 +33,7 @@
 #include <wx/stattext.h>
 #include "macros.h"
 #include <algorithm>
+#include "windowattrmanager.h"
 
 DEFINE_EVENT_TYPE(wxEVT_FRD_FIND_NEXT)
 DEFINE_EVENT_TYPE(wxEVT_FRD_CLOSE)
@@ -89,11 +90,13 @@ bool FindReplaceDialog::Create(wxWindow* parent,
 
     CreateGUIControls();
     ConnectEvents();
-
+    
+    SetName("FindAndReplaceDialog");
+    WindowAttrManager::Load(this);
     GetSizer()->Fit(this);
-    Centre();
-
+    SetMinClientSize(GetSize());
     m_findString->SetFocus();
+    CentreOnParent();
     return true;
 }
 
