@@ -51,15 +51,6 @@
 #include "editor_config.h"
 #include "codelite_events.h"
 
-// Custom styles
-#define LEX_FIF_DEFAULT 0
-#define LEX_FIF_FILE 1
-#define LEX_FIF_MATCH 2
-#define LEX_FIF_LINE_NUMBER 3
-#define LEX_FIF_HEADER 4
-#define LEX_FIF_SCOPE 5
-#define LEX_FIF_MATCH_COMMENT 6
-
 BEGIN_EVENT_TABLE(FindResultsTab, OutputTabWindow)
 EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_SEARCHSTARTED, FindResultsTab::OnSearchStart)
 EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_MATCHFOUND, FindResultsTab::OnSearchMatch)
@@ -68,8 +59,6 @@ EVT_COMMAND(wxID_ANY, wxEVT_SEARCH_THREAD_SEARCHCANCELED, FindResultsTab::OnSear
 EVT_UPDATE_UI(XRCID("hold_pane_open"), FindResultsTab::OnHoldOpenUpdateUI)
 END_EVENT_TABLE()
 
-FindResultsTab::eState FindResultsTab::m_curstate = FindResultsTab::kStartOfLine;
-
 FindResultsTab::FindResultsTab(wxWindow* parent, wxWindowID id, const wxString& name)
     : OutputTabWindow(parent, id, name)
     , m_searchInProgress(false)
@@ -108,90 +97,7 @@ FindResultsTab::~FindResultsTab()
         wxCommandEventHandler(FindResultsTab::OnFindInFiles), NULL, this);
 }
 
-void FindResultsTab::SetStyles(wxStyledTextCtrl* sci)
-{
-    LexerConf::Ptr_t lexer = ColoursAndFontsManager::Get().GetLexer("c++");
-    if(!lexer) {
-        lexer = ColoursAndFontsManager::Get().GetLexer("text");
-    }
-
-    const StyleProperty& defaultStyle = lexer->GetProperty(0);
-    wxFont defaultFont = lexer->GetFontForSyle(0);
-
-    for(size_t i = 0; i < wxSTC_STYLE_MAX; ++i) {
-        sci->StyleSetForeground(i, defaultStyle.GetFgColour());
-        sci->StyleSetBackground(i, defaultStyle.GetBgColour());
-        sci->StyleSetFont(i, defaultFont);
-    }
-
-    // Show/hide whitespace
-    sci->SetViewWhiteSpace(EditorConfigST::Get()->GetOptions()->GetShowWhitspaces());
-    StyleProperty::Map_t& props = lexer->GetLexerProperties();
-    // Set the whitespace colours
-    sci->SetWhitespaceForeground(true, props[WHITE_SPACE_ATTR_ID].GetFgColour());
-
-    sci->StyleSetForeground(LEX_FIF_HEADER, props[11].GetFgColour());
-    sci->StyleSetBackground(LEX_FIF_HEADER, props[11].GetBgColour());
-
-    // 33 is the style for line numbers
-    sci->StyleSetForeground(LEX_FIF_LINE_NUMBER, props[33].GetFgColour());
-
-    // 11 is the style number for "identifier"
-    sci->StyleSetForeground(LEX_FIF_MATCH, props[11].GetFgColour());
-
-    // 16 is the stule for colouring classes
-    sci->StyleSetForeground(LEX_FIF_SCOPE, props[16].GetFgColour());
-
-    sci->StyleSetForeground(LEX_FIF_MATCH_COMMENT, props[wxSTC_C_COMMENTLINE].GetFgColour());
-
-    sci->StyleSetForeground(LEX_FIF_FILE, props[wxSTC_C_WORD].GetFgColour());
-    sci->StyleSetEOLFilled(LEX_FIF_FILE, true);
-
-    sci->StyleSetForeground(LEX_FIF_DEFAULT, props[11].GetFgColour());
-    sci->StyleSetBackground(LEX_FIF_DEFAULT, props[11].GetBgColour());
-
-    sci->StyleSetHotSpot(LEX_FIF_MATCH, true);
-    sci->StyleSetHotSpot(LEX_FIF_FILE, true);
-    sci->StyleSetHotSpot(LEX_FIF_MATCH_COMMENT, true);
-
-    sci->SetHotspotActiveForeground(true, lexer->IsDark() ? "WHITE" : "BLACK");
-    sci->SetHotspotActiveUnderline(false);
-    sci->MarkerDefine(7, wxSTC_MARK_ARROW);
-
-#if wxVERSION_NUMBER < 3100
-    // On GTK we dont have the wxSTC_INDIC_TEXTFORE symbol yet (old wx version)
-    sci->MarkerDefine(7, wxSTC_MARK_ARROW);
-    sci->MarkerSetBackground(7, lexer->IsDark() ? "CYAN" : "ORANGE");
-    sci->MarkerSetForeground(7, lexer->IsDark() ? "CYAN" : "ORANGE");
-
-    sci->IndicatorSetForeground(1, lexer->IsDark() ? "CYAN" : "ORANGE");
-    sci->IndicatorSetStyle(1, wxSTC_INDIC_ROUNDBOX);
-#else
-    sci->MarkerDefine(7, wxSTC_MARK_ARROW);
-    sci->MarkerSetBackground(7, lexer->IsDark() ? "#FFD700" : "#FF4500");
-    sci->MarkerSetForeground(7, lexer->IsDark() ? "#FFD700" : "#FF4500");
-
-    sci->IndicatorSetForeground(1, lexer->IsDark() ? "#FFD700" : "#FF4500");
-    sci->IndicatorSetStyle(1, wxSTC_INDIC_TEXTFORE);
-#endif
-    sci->IndicatorSetUnder(1, true);
-
-    sci->SetMarginWidth(0, 0);
-    sci->SetMarginWidth(1, 16);
-    sci->SetMarginWidth(2, 0);
-    sci->SetMarginWidth(3, 0);
-    sci->SetMarginWidth(4, 0);
-    sci->SetMarginSensitive(1, true);
-    sci->HideSelection(true);
-
-    // Indentation
-    OptionsConfigPtr options = EditorConfigST::Get()->GetOptions();
-    sci->SetUseTabs(options->GetIndentUsesTabs());
-    sci->SetTabWidth(options->GetIndentWidth());
-    sci->SetIndent(options->GetIndentWidth());
-
-    sci->Refresh();
-}
+void FindResultsTab::SetStyles(wxStyledTextCtrl* sci) { m_styler->SetStyles(sci); }
 
 void FindResultsTab::AppendText(const wxString& line)
 {
@@ -205,7 +111,7 @@ void FindResultsTab::Clear()
     m_indicators.clear();
     m_searchTitle.clear();
     OutputTabWindow::Clear();
-    m_curstate = kStartOfLine;
+    m_styler->Reset();
 }
 
 void FindResultsTab::OnFindInFiles(wxCommandEvent& e)
@@ -214,12 +120,12 @@ void FindResultsTab::OnFindInFiles(wxCommandEvent& e)
         ::wxMessageBox(_("The search thread is currently busy"), _("CodeLite"), wxICON_INFORMATION | wxOK);
         return;
     }
-    
+
     // Fire the wxEVT_CMD_FIND_IN_FILES_SHOWING showing event
     clCommandEvent fifDlgShowing(wxEVT_CMD_FIND_IN_FILES_SHOWING);
     EventNotifier::Get()->ProcessEvent(fifDlgShowing);
-    
-    // Display the Find In Files dialog 
+
+    // Display the Find In Files dialog
     FindInFilesDialog dlg(EventNotifier::Get()->TopFrame(), "FindInFilesData", fifDlgShowing.GetStrings());
     wxArrayString* paths = (wxArrayString*)e.GetClientData();
     if(paths) {
@@ -370,15 +276,16 @@ void FindResultsTab::OnRepeatOutputUI(wxUpdateUIEvent& e) { e.Enable(m_sci->GetL
 
 void FindResultsTab::OnMouseDClick(wxStyledTextEvent& e)
 {
-    long pos = e.GetPosition();
-    int line = m_sci->LineFromPosition(pos);
-    int style = m_sci->GetStyleAt(pos);
+    int clickedLine = wxNOT_FOUND;
+    m_styler->HitTest(m_sci, e, clickedLine);
 
-    if(style == LEX_FIF_FILE || style == LEX_FIF_HEADER) {
-        m_sci->ToggleFold(line);
+    // Did we clicked on a togglable line?
+    int toggleLine = m_styler->TestToggle(m_sci, e);
+    if(toggleLine != wxNOT_FOUND) {
+        m_sci->ToggleFold(toggleLine);
 
     } else {
-        MatchInfo_t::const_iterator m = m_matchInfo.find(line);
+        MatchInfo_t::const_iterator m = m_matchInfo.find(clickedLine);
         if(m != m_matchInfo.end()) {
             DoOpenSearchResult(m->second, m_sci, m->first);
         }
@@ -529,114 +436,7 @@ void FindResultsTab::OnStyleNeeded(wxStyledTextEvent& e)
 
 void FindResultsTab::StyleText(wxStyledTextCtrl* ctrl, wxStyledTextEvent& e, bool hasSope)
 {
-    int startPos = ctrl->GetEndStyled();
-    int endPos = e.GetPosition();
-    wxString text = ctrl->GetTextRange(startPos, endPos);
-    ctrl->StartStyling(startPos, 0x1f); // text styling
-
-    wxString::const_iterator iter = text.begin();
-    size_t headerStyleLen = 0;
-    size_t filenameStyleLen = 0;
-    size_t lineNumberStyleLen = 0;
-    size_t scopeStyleLen = 0;
-    size_t matchStyleLen = 0;
-    size_t i = 0;
-    for(; iter != text.end(); ++iter) {
-        const wxUniChar& ch = *iter;
-        switch(m_curstate) {
-        default:
-            break;
-        case kStartOfLine:
-            if(ch == '=') {
-                m_curstate = kHeader;
-                headerStyleLen = 1;
-            } else if(ch == ' ') {
-                // start of a line number
-                lineNumberStyleLen = 1;
-                m_curstate = kLineNumber;
-            } else if(ch == '\n') {
-                ctrl->SetStyling(1, LEX_FIF_DEFAULT);
-            } else {
-                // File name
-                filenameStyleLen = 1;
-                m_curstate = kFile;
-            }
-            break;
-        case kLineNumber:
-            ++lineNumberStyleLen;
-            if(ch == ':') {
-                ctrl->SetStyling(lineNumberStyleLen, LEX_FIF_LINE_NUMBER);
-                lineNumberStyleLen = 0;
-                if(hasSope) {
-                    // the scope showed by displayed after the line number
-                    m_curstate = kScope;
-                } else {
-                    // No scope, from hereon, match until EOF
-                    m_curstate = kMatch;
-                }
-            }
-            break;
-        case kScope:
-            ++scopeStyleLen;
-            if(ch == ']') {
-                // end of scope
-                ctrl->SetStyling(scopeStyleLen, LEX_FIF_SCOPE);
-                scopeStyleLen = 0;
-                m_curstate = kMatch;
-            }
-            break;
-        case kMatch:
-            ++matchStyleLen;
-            if(ch == '\n') {
-                m_curstate = kStartOfLine;
-                ctrl->SetStyling(matchStyleLen, LEX_FIF_MATCH);
-                matchStyleLen = 0;
-            }
-            break;
-        case kFile:
-            ++filenameStyleLen;
-            if(ch == '\n') {
-                m_curstate = kStartOfLine;
-                ctrl->SetFoldLevel(ctrl->LineFromPosition(startPos + i), 2 | wxSTC_FOLDLEVELHEADERFLAG);
-                ctrl->SetStyling(filenameStyleLen, LEX_FIF_FILE);
-                filenameStyleLen = 0;
-            }
-            break;
-        case kHeader:
-            ++headerStyleLen;
-            if(ch == '\n') {
-                m_curstate = kStartOfLine;
-                ctrl->SetFoldLevel(ctrl->LineFromPosition(startPos + i), 1 | wxSTC_FOLDLEVELHEADERFLAG);
-                ctrl->SetStyling(headerStyleLen, LEX_FIF_HEADER);
-                headerStyleLen = 0;
-            }
-            break;
-        }
-        ++i;
-    }
-
-    // Left overs...
-    if(headerStyleLen) {
-        ctrl->SetFoldLevel(ctrl->LineFromPosition(startPos + i), 1 | wxSTC_FOLDLEVELHEADERFLAG);
-        ctrl->SetStyling(headerStyleLen, LEX_FIF_HEADER);
-        headerStyleLen = 0;
-    }
-
-    if(filenameStyleLen) {
-        ctrl->SetFoldLevel(ctrl->LineFromPosition(startPos + i), 2 | wxSTC_FOLDLEVELHEADERFLAG);
-        ctrl->SetStyling(filenameStyleLen, LEX_FIF_FILE);
-        filenameStyleLen = 0;
-    }
-
-    if(matchStyleLen) {
-        ctrl->SetStyling(matchStyleLen, LEX_FIF_MATCH);
-        matchStyleLen = 0;
-    }
-
-    if(lineNumberStyleLen) {
-        ctrl->SetStyling(lineNumberStyleLen, LEX_FIF_LINE_NUMBER);
-        lineNumberStyleLen = 0;
-    }
+    m_styler->StyleText(ctrl, e, hasSope);
 }
 
 void FindResultsTab::OnThemeChanged(wxCommandEvent& e)
@@ -709,7 +509,7 @@ void FindResultsTab::LoadSearch(const History& h)
 
 void FindResultsTab::OnRecentSearchesUI(wxUpdateUIEvent& e) { e.Enable(!m_history.IsEmpty() && !m_searchInProgress); }
 
-void FindResultsTab::ResetStyler() { m_curstate = kStartOfLine; }
+void FindResultsTab::ResetStyler() { m_styler->Reset(); }
 
 /////////////////////////////////////////////////////////////////////////////////
 
