@@ -38,7 +38,7 @@
 FindUsageTab::FindUsageTab(wxWindow* parent, const wxString& name)
     : OutputTabWindow(parent, wxID_ANY, name)
 {
-    FindResultsTab::SetStyles(m_sci);
+    m_styler->SetStyles(m_sci);
     m_sci->HideSelection(true);
     m_sci->Connect(wxEVT_STC_STYLENEEDED, wxStyledTextEventHandler(FindUsageTab::OnStyleNeeded), NULL, this);
     m_tb->DeleteTool(XRCID("repeat_output"));
@@ -57,13 +57,13 @@ void FindUsageTab::OnStyleNeeded(wxStyledTextEvent& e)
 {
     wxStyledTextCtrl* ctrl = dynamic_cast<wxStyledTextCtrl*>(e.GetEventObject());
     if(!ctrl) return;
-    FindResultsTab::StyleText(ctrl, e, true);
+    m_styler->StyleText(ctrl, e, true);
 }
 
 void FindUsageTab::Clear()
 {
     m_matches.clear();
-    FindResultsTab::ResetStyler();
+    m_styler->Reset();
     OutputTabWindow::Clear();
 }
 
@@ -71,14 +71,20 @@ void FindUsageTab::OnClearAll(wxCommandEvent& e) { Clear(); }
 
 void FindUsageTab::OnMouseDClick(wxStyledTextEvent& e)
 {
-    long pos = e.GetPosition();
-    int line = m_sci->LineFromPosition(pos);
-    UsageResultsMap::const_iterator iter = m_matches.find(line);
-    if(iter != m_matches.end()) {
-        DoOpenResult(iter->second);
-    }
+    int clickedLine = wxNOT_FOUND;
+    m_styler->HitTest(m_sci, e, clickedLine);
 
-    m_sci->SetSelection(wxNOT_FOUND, pos);
+    // Did we clicked on a togglable line?
+    int toggleLine = m_styler->TestToggle(m_sci, e);
+    if(toggleLine != wxNOT_FOUND) {
+        m_sci->ToggleFold(toggleLine);
+
+    } else {
+        UsageResultsMap::const_iterator iter = m_matches.find(clickedLine);
+        if(iter != m_matches.end()) {
+            DoOpenResult(iter->second);
+        }
+    }
 }
 
 void FindUsageTab::OnClearAllUI(wxUpdateUIEvent& e) { e.Enable(m_sci && m_sci->GetLength()); }
@@ -177,5 +183,5 @@ void FindUsageTab::OnHoldOpenUpdateUI(wxUpdateUIEvent& e)
 void FindUsageTab::OnThemeChanged(wxCommandEvent& e)
 {
     e.Skip();
-    FindResultsTab::SetStyles(m_sci);
+    m_styler->SetStyles(m_sci);
 }
