@@ -103,8 +103,8 @@ void OutputPane::CreateGUIControls()
         style |= kNotebook_RightTabs;
 #endif
     }
-    //style |= kNotebook_UnderlineActiveTab;
-    
+    style |= kNotebook_UnderlineActiveTab;
+
     m_book = new Notebook(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, style);
 
     BitmapLoader* bmpLoader = PluginManager::Get()->GetStdIcons();
@@ -123,15 +123,14 @@ void OutputPane::CreateGUIControls()
     m_buildWin = new NewBuildTab(m_book);
     m_book->AddPage(m_buildWin, wxGetTranslation(BUILD_WIN), true, bmpLoader->LoadBitmap(wxT("build")));
     m_tabs.insert(std::make_pair(wxGetTranslation(BUILD_WIN),
-                                 Tab(wxGetTranslation(BUILD_WIN), m_buildWin, bmpLoader->LoadBitmap(wxT("build")))));
+        Tab(wxGetTranslation(BUILD_WIN), m_buildWin, bmpLoader->LoadBitmap(wxT("build")))));
     mgr->AddOutputTab(wxGetTranslation(BUILD_WIN));
 
     // Find in files
     m_findResultsTab = new FindResultsTab(m_book, wxID_ANY, wxGetTranslation(FIND_IN_FILES_WIN));
     m_book->AddPage(m_findResultsTab, wxGetTranslation(FIND_IN_FILES_WIN), false, bmpLoader->LoadBitmap(wxT("find")));
-    m_tabs.insert(
-        std::make_pair(wxGetTranslation(FIND_IN_FILES_WIN),
-                       Tab(wxGetTranslation(FIND_IN_FILES_WIN), m_findResultsTab, bmpLoader->LoadBitmap(wxT("find")))));
+    m_tabs.insert(std::make_pair(wxGetTranslation(FIND_IN_FILES_WIN),
+        Tab(wxGetTranslation(FIND_IN_FILES_WIN), m_findResultsTab, bmpLoader->LoadBitmap(wxT("find")))));
     mgr->AddOutputTab(wxGetTranslation(FIND_IN_FILES_WIN));
 
     // Replace In Files
@@ -145,35 +144,29 @@ void OutputPane::CreateGUIControls()
     // Show Usage ("References")
     m_showUsageTab = new FindUsageTab(m_book, wxGetTranslation(SHOW_USAGE));
     m_book->AddPage(m_showUsageTab, wxGetTranslation(SHOW_USAGE), false, bmpLoader->LoadBitmap(wxT("find")));
-    m_tabs.insert(
-        std::make_pair(wxGetTranslation(SHOW_USAGE),
-                       Tab(wxGetTranslation(SHOW_USAGE), m_showUsageTab, bmpLoader->LoadBitmap(wxT("find")))));
+    m_tabs.insert(std::make_pair(wxGetTranslation(SHOW_USAGE),
+        Tab(wxGetTranslation(SHOW_USAGE), m_showUsageTab, bmpLoader->LoadBitmap(wxT("find")))));
     mgr->AddOutputTab(wxGetTranslation(SHOW_USAGE));
 
     // Output tab
     m_outputWind = new OutputTab(m_book, wxID_ANY, wxGetTranslation(OUTPUT_WIN));
     m_book->AddPage(m_outputWind, wxGetTranslation(OUTPUT_WIN), false, bmpLoader->LoadBitmap(wxT("console")));
-    m_tabs.insert(
-        std::make_pair(wxGetTranslation(OUTPUT_WIN),
-                       Tab(wxGetTranslation(OUTPUT_WIN), m_outputWind, bmpLoader->LoadBitmap(wxT("console")))));
+    m_tabs.insert(std::make_pair(wxGetTranslation(OUTPUT_WIN),
+        Tab(wxGetTranslation(OUTPUT_WIN), m_outputWind, bmpLoader->LoadBitmap(wxT("console")))));
     mgr->AddOutputTab(wxGetTranslation(OUTPUT_WIN));
 
 #if HAS_LIBCLANG
     // Clang tab
     NewProjImgList images;
     m_clangOutputTab = new ClangOutputTab(m_book);
-    m_book->AddPage(m_clangOutputTab, wxGetTranslation(CLANG_TAB), false, images.Bitmap("clang16"));
+    m_book->AddPage(m_clangOutputTab, wxGetTranslation(CLANG_TAB), false, bmpLoader->LoadBitmap("clang"));
     m_tabs.insert(std::make_pair(wxGetTranslation(CLANG_TAB),
-                                 Tab(wxGetTranslation(CLANG_TAB), m_clangOutputTab, images.Bitmap("clang16"))));
+        Tab(wxGetTranslation(CLANG_TAB), m_clangOutputTab, bmpLoader->LoadBitmap("clang"))));
     mgr->AddOutputTab(wxGetTranslation(CLANG_TAB));
 #endif
 
-    wxTextCtrl* text = new wxTextCtrl(m_book,
-                                      wxID_ANY,
-                                      wxEmptyString,
-                                      wxDefaultPosition,
-                                      wxDefaultSize,
-                                      wxTE_RICH2 | wxTE_MULTILINE | wxTE_READONLY | wxHSCROLL);
+    wxTextCtrl* text = new wxTextCtrl(m_book, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize,
+        wxTE_RICH2 | wxTE_MULTILINE | wxTE_READONLY | wxHSCROLL);
 
     /////////////////////////////////////
     // Set the trace's font & colors
@@ -181,8 +174,8 @@ void OutputPane::CreateGUIControls()
 
     m_book->AddPage(text, wxGetTranslation(TRACE_TAB), false, bmpLoader->LoadBitmap("log"));
     m_logTargetOld = wxLog::SetActiveTarget(new wxclTextCtrl(text));
-    m_tabs.insert(std::make_pair(wxGetTranslation(TRACE_TAB),
-                                 Tab(wxGetTranslation(TRACE_TAB), text, bmpLoader->LoadBitmap("log"))));
+    m_tabs.insert(std::make_pair(
+        wxGetTranslation(TRACE_TAB), Tab(wxGetTranslation(TRACE_TAB), text, bmpLoader->LoadBitmap("log"))));
     mgr->AddOutputTab(wxGetTranslation(TRACE_TAB));
 
     // Now that we set up our own log target, re-enable the logging
@@ -191,8 +184,8 @@ void OutputPane::CreateGUIControls()
     // Tasks panel
     m_taskPanel = new TaskPanel(m_book, wxID_ANY, wxGetTranslation(TASKS));
     m_book->AddPage(m_taskPanel, wxGetTranslation(TASKS), false, bmpLoader->LoadBitmap("tasks"));
-    m_tabs.insert(std::make_pair(wxGetTranslation(TASKS),
-                                 Tab(wxGetTranslation(TASKS), m_taskPanel, bmpLoader->LoadBitmap("tasks"))));
+    m_tabs.insert(std::make_pair(
+        wxGetTranslation(TASKS), Tab(wxGetTranslation(TASKS), m_taskPanel, bmpLoader->LoadBitmap("tasks"))));
     mgr->AddOutputTab(wxGetTranslation(TASKS));
 
     SetMinSize(wxSize(200, 100));
