@@ -29,6 +29,7 @@
 #include "wxcrafter.h"
 #include "theme_handler_helper.h"
 #include "cl_command_event.h"
+#include "clTreeKeyboardInput.h"
 
 class IManager;
 class svSymbolTree;
@@ -36,13 +37,22 @@ class svSymbolTree;
 class OutlineTab : public OutlineTabBaseClass
 {
 protected:
-    virtual void OnPhpItemActivated(wxTreeEvent& event);
-    virtual void OnPhpItemSelected(wxTreeEvent& event);
     IManager* m_mgr;
     svSymbolTree* m_tree;
     ThemeHandlerHelper* m_themeHelper;
-    bool IsIncludeFileNode();
     wxFileName m_phpFile;
+    clTreeKeyboardInput::Ptr_t m_phpKeyboardHelper;
+    clTreeKeyboardInput::Ptr_t m_cxxKeyboardHelper;
+    bool m_sortCxxTreeAlphabetically;
+
+protected:
+    virtual void OnSortAlpha(wxCommandEvent& event);
+    virtual void OnSortAlphaUI(wxUpdateUIEvent& event);
+    virtual void OnPhpItemActivated(wxTreeEvent& event);
+    virtual void OnPhpItemSelected(wxTreeEvent& event);
+    bool IsIncludeFileNode();
+
+    void DoRefreshCxxView();
 
 public:
     OutlineTab(wxWindow* parent, IManager* mgr);
