@@ -1,3 +1,28 @@
+//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+//
+// Copyright            : (C) 2015 Eran Ifrah
+// File name            : ColoursAndFontsManager.h
+//
+// -------------------------------------------------------------------------
+// A
+//              _____           _      _     _ _
+//             /  __ \         | |    | |   (_) |
+//             | /  \/ ___   __| | ___| |    _| |_ ___
+//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
+//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
+//              \____/\___/ \__,_|\___\_____/_|\__\___|
+//
+//                                                  F i l e
+//
+//    This program is free software; you can redistribute it and/or modify
+//    it under the terms of the GNU General Public License as published by
+//    the Free Software Foundation; either version 2 of the License, or
+//    (at your option) any later version.
+//
+//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
 #ifndef LEXERCONFMANAGER_H
 #define LEXERCONFMANAGER_H
 
@@ -9,12 +34,7 @@
 #include <wx/filename.h>
 #include <wx/event.h>
 #include "cl_command_event.h"
-
-// Upgrade macros
-#define LEXERS_VERSION_STRING "LexersVersion"
-#define LEXERS_VERSION 2
-
-// Define the upgrade steps
+#include <wx/font.h>
 
 // When the version is 0, it means that we need to upgrade the colours for the line numbers
 // and for the default state
@@ -35,35 +55,37 @@ protected:
     ColoursAndFontsManager::Vec_t m_allLexers;
     wxColour m_globalBgColour;
     wxColour m_globalFgColour;
+    wxString m_globalTheme;
     LexerConf::Ptr_t m_defaultLexer;
     int m_lexersVersion;
-    
+    wxFont m_globalFont;
+
 private:
     ColoursAndFontsManager();
     virtual ~ColoursAndFontsManager();
 
-    void LoadNewXmls(const std::vector<wxXmlDocument*>& xmlFiles, bool userLexers = false);
-    void LoadOldXmls(const wxString& path);
+    void LoadOldXmls(const std::vector<wxXmlDocument*>& xmlFiles, bool userLexers = false);
     LexerConf::Ptr_t DoAddLexer(wxXmlNode* node);
+    LexerConf::Ptr_t DoAddLexer(JSONElement json);
     void Clear();
     wxFileName GetConfigFile() const;
-    void SaveGlobalSettings();
+    void LoadJSON(const wxFileName& path);
 
 public:
     static ColoursAndFontsManager& Get();
-    
+
+    /**
+     * @brief save the global settings
+     */
+    void SaveGlobalSettings();
     /**
      * @brief adjust the lexer colours to fit codelite's general look and feel
      */
     void UpdateLexerColours(LexerConf::Ptr_t lexer, bool force);
-    
+
     const wxColour& GetGlobalBgColour() const { return m_globalBgColour; }
     const wxColour& GetGlobalFgColour() const { return m_globalFgColour; }
-    
-    bool IsUpgradeNeeded() const {
-        return m_lexersVersion != LEXERS_VERSION;
-    }
-    
+
     /**
      * @brief create new theme for a lexer by copying an existing theme 'sourceTheme'
      * @param lexerName the lexer name
@@ -77,11 +99,17 @@ public:
         this->m_globalBgColour = globalBgColour;
         SaveGlobalSettings();
     }
+
+    void SetGlobalFont(const wxFont& font);
+    const wxFont& GetGlobalFont() const;
+
     void SetGlobalFgColour(const wxColour& globalFgColour)
     {
         this->m_globalFgColour = globalFgColour;
         SaveGlobalSettings();
     }
+    void SetGlobalTheme(const wxString& globalTheme) { this->m_globalTheme = globalTheme; }
+    const wxString& GetGlobalTheme() const { return m_globalTheme; }
     /**
      * @brief reload the lexers from the configuration files
      */
@@ -95,12 +123,7 @@ public:
     /**
      * @brief save the lexers into their proper file name
      */
-    void Save(bool userLexers = false);
-
-    /**
-     * @brief save a single lexer
-     */
-    void Save(LexerConf::Ptr_t lexer);
+    void Save();
 
     /**
      * @brief set the active theme for a lexer by name
@@ -143,8 +166,19 @@ public:
      * @brief callback called by the helper thread indicating that it finished caching
      * the XML files
      */
-    void OnLexerFilesLoaded(const std::vector<wxXmlDocument*>& defaultLexers,
-                            const std::vector<wxXmlDocument*>& userLexers);
+    void OnLexerFilesLoaded(const std::vector<wxXmlDocument*>& userLexers);
+
+    /**
+     * @brief set a unified theme for all lexers. If the requested theme is not available for a given lexer,
+     * use the closest one
+     * @param themeName
+     */
+    void SetTheme(const wxString& themeName);
+
+    /**
+     * @brief add new lexer (replace an existing one if exists)
+     */
+    void AddLexer(LexerConf::Ptr_t lexer);
 };
 
 #endif // LEXERCONFMANAGER_H
