@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 //
-// copyright            : (C) 2014 The CodeLite Team
+// copyright            : (C) 2014 Eran Ifrah
 // file name            : DiffSideBySidePanel.h
 //
 // -------------------------------------------------------------------------
@@ -70,14 +70,15 @@ public:
         kLeftReadOnly = (1 << 2),
         kRightReadOnly = (1 << 3),
         kOriginSourceControl = (1 << 4),
+        kSavePaths = (1 << 5),
     };
 
 protected:
+    virtual void OnBrowseLeftFile(wxCommandEvent& event);
+    virtual void OnBrowseRightFile(wxCommandEvent& event);
     virtual void OnMouseWheel(wxMouseEvent& event);
     virtual void OnSingleUI(wxUpdateUIEvent& event);
-    virtual void OnSingleView(wxRibbonButtonBarEvent& event);
-    virtual void OnCopyLeftToRightMenu(wxRibbonButtonBarEvent& event);
-    virtual void OnCopyRightToLeftMenu(wxRibbonButtonBarEvent& event);
+    virtual void OnSingleView(wxCommandEvent& event);
     virtual void OnLeftPickerUI(wxUpdateUIEvent& event);
     virtual void OnRightPickerUI(wxUpdateUIEvent& event);
 
@@ -110,23 +111,23 @@ protected:
 
 protected:
     virtual void OnRefreshDiffUI(wxUpdateUIEvent& event);
-    virtual void OnHorizontal(wxRibbonButtonBarEvent& event);
+    virtual void OnHorizontal(wxCommandEvent& event);
     virtual void OnHorizontalUI(wxUpdateUIEvent& event);
-    virtual void OnVertical(wxRibbonButtonBarEvent& event);
+    virtual void OnVertical(wxCommandEvent& event);
     virtual void OnVerticalUI(wxUpdateUIEvent& event);
-    virtual void OnCopyFileFromRight(wxRibbonButtonBarEvent& event);
-    virtual void OnCopyFileLeftToRight(wxRibbonButtonBarEvent& event);
-    virtual void OnSaveChanges(wxRibbonButtonBarEvent& event);
+    virtual void OnCopyFileFromRight(wxCommandEvent& event);
+    virtual void OnCopyFileLeftToRight(wxCommandEvent& event);
+    virtual void OnSaveChanges(wxCommandEvent& event);
     virtual void OnSaveChangesUI(wxUpdateUIEvent& event);
-    virtual void OnCopyLeftToRight(wxRibbonButtonBarEvent& event);
-    virtual void OnCopyRightToLeft(wxRibbonButtonBarEvent& event);
+    virtual void OnCopyLeftToRight(wxCommandEvent& event);
+    virtual void OnCopyRightToLeft(wxCommandEvent& event);
     virtual void OnCopyLeftToRightUI(wxUpdateUIEvent& event);
     virtual void OnCopyRightToLeftUI(wxUpdateUIEvent& event);
     virtual void OnNextDiffUI(wxUpdateUIEvent& event);
     virtual void OnPrevDiffUI(wxUpdateUIEvent& event);
-    virtual void OnNextDiffSequence(wxRibbonButtonBarEvent& event);
-    virtual void OnPrevDiffSequence(wxRibbonButtonBarEvent& event);
-    virtual void OnRefreshDiff(wxRibbonButtonBarEvent& event);
+    virtual void OnNextDiffSequence(wxCommandEvent& event);
+    virtual void OnPrevDiffSequence(wxCommandEvent& event);
+    virtual void OnRefreshDiff(wxCommandEvent& event);
     virtual void OnLeftStcPainted(wxStyledTextEvent& event);
     virtual void OnRightStcPainted(wxStyledTextEvent& event);
     void OnPageClosing(wxNotifyEvent& event);
@@ -138,10 +139,10 @@ protected:
     void DoCopyCurrentSequence(wxStyledTextCtrl* from, wxStyledTextCtrl* to);
     void DoCopyFileContent(wxStyledTextCtrl* from, wxStyledTextCtrl* to);
     void DoGetPositionsToCopy(wxStyledTextCtrl* stc,
-                              int& startPos,
-                              int& endPos,
-                              int& placeHolderMarkerFirstLine,
-                              int& placeHolderMarkerLastLine);
+        int& startPos,
+        int& endPos,
+        int& placeHolderMarkerFirstLine,
+        int& placeHolderMarkerLastLine);
     void DoSave(wxStyledTextCtrl* stc, const wxFileName& fn);
 
     bool CanNextDiff();
@@ -167,7 +168,12 @@ public:
      * @brief start a new empty diff
      */
     void DiffNew();
-
+    
+    /**
+     * @brief start a new diff for two input files
+     */
+    void DiffNew(const wxFileName& left, const wxFileName& right);
+    
     /**
      * @brief set the initial files to diff
      * Once set, you should call Diff() function
