@@ -7,13 +7,14 @@
 
 EclipseCXXThemeImporter::EclipseCXXThemeImporter()
 {
-    SetKeywords0("and and_eq asm auto bitand bitor bool break case catch char class compl const const_cast "
-                 "continue default delete do double dynamic_cast else enum explicit export extern false final "
-                 "float for friend goto if inline int long mutable namespace new not not_eq operator or "
-                 "or_eq private protected public register reinterpret_cast return short signed sizeof "
-                 "static static_cast struct switch template this throw true try typedef typeid typename "
-                 "union unsigned using virtual void volatile wchar_t while xor xor_eq alignas alignof "
-                 "char16_t char32_t constexpr decltype noexcept nullptr static_assert thread_local");
+    SetKeywords0(
+        "and and_eq asm auto bitand bitor bool break case catch char class compl const const_cast "
+        "continue default delete do double dynamic_cast else enum explicit export extern false final "
+        "float for friend goto if inline int long mutable namespace new not not_eq operator or "
+        "or_eq override private protected public register reinterpret_cast return short signed sizeof "
+        "static static_cast struct switch template this throw true try typedef typeid typename "
+        "union unsigned using virtual void volatile wchar_t while xor xor_eq alignas alignof "
+        "char16_t char32_t constexpr decltype noexcept nullptr static_assert thread_local");
 
     SetKeywords1("abstract boolean break byte case catch char class const continue debugger default delete "
                  "do double else enum export extends final finally float for function goto if implements "
