@@ -26,6 +26,7 @@
 #include "clDebuggerTerminal.h"
 #include "globals.h"
 #include "file_logger.h"
+#include "procutils.h"
 
 #ifndef __WXMSW__
 #   include <sys/wait.h>
@@ -65,8 +66,26 @@ void clDebuggerTerminalPOSIX::Clear()
 {
 #ifndef __WXMSW__
     if ( m_pid != wxNOT_FOUND ) {
+        // konsole hangs on exit with the message  "Warning: Program '/bin/sleep' crashed."
+        // I can't find any way to prevent this, so grab the terminal's pid so we can kill it too if it's konsole
+        bool killParent(false); // There's no need to kill non-konsole terminals
+        wxString command(wxString::Format("ps -o ppid= -p %i", (int)m_pid));
+        wxString result = ProcUtils::SafeExecuteCommand(command);
+        long parentID;
+        if (result.Trim().ToLong(&parentID)) {
+            wxString command(wxString::Format("ps -o command= -p %i", (int)parentID));
+            wxString name = ProcUtils::SafeExecuteCommand(command);
+            if (name.Contains("--separate")) { 
+                killParent = true; //It _is_ konsole, which will have been launched with --separate as an option
+            }
+        }
+        
         // terminate the process
-        ::wxKill(m_pid, wxSIGKILL);
+        ::wxKill(m_pid, wxSIGTERM);
+        
+        if (killParent) {
+            ::wxKill(parentID, wxSIGTERM);
+        }
     }
 #endif
     m_pid = wxNOT_FOUND;
