@@ -45,6 +45,8 @@
 #include "compiler_command_line_parser.h"
 #include <algorithm>
 #include "wxArrayStringAppender.h"
+#include <wx/regex.h>
+#include "macromanager.h"
 
 const wxString Project::STATIC_LIBRARY = wxT("Static Library");
 const wxString Project::DYNAMIC_LIBRARY = wxT("Dynamic Library");
@@ -76,11 +78,11 @@ Project::~Project()
 bool Project::Create(const wxString& name, const wxString& description, const wxString& path, const wxString& projType)
 {
     m_vdCache.clear();
-    
+
     m_fileName = wxFileName(path, name);
     m_fileName.SetExt("project");
     m_fileName.MakeAbsolute();
-    
+
     // Ensure that the target folder exists
     m_fileName.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
     m_projectPath = m_fileName.GetPath();
@@ -88,13 +90,14 @@ bool Project::Create(const wxString& name, const wxString& description, const wx
     wxXmlNode* root = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("CodeLite_Project"));
     m_doc.SetRoot(root);
     m_doc.GetRoot()->AddProperty(wxT("Name"), name);
-
+    m_doc.GetRoot()->AddAttribute("Version", WORKSPACE_XML_VERSION);
+    
     wxXmlNode* descNode = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("Description"));
     XmlUtils::SetNodeContent(descNode, description);
     m_doc.GetRoot()->AddChild(descNode);
 
     // Create the default virtual directories
-    wxXmlNode* srcNode = NULL, * headNode = NULL;
+    wxXmlNode *srcNode = NULL, *headNode = NULL;
 
     srcNode = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("VirtualDirectory"));
     srcNode->AddProperty(wxT("Name"), wxT("src"));
@@ -388,6 +391,13 @@ bool Project::SaveXmlFile()
 {
     wxString projectXml;
     wxStringOutputStream sos(&projectXml);
+    
+    // Set the workspace XML version
+    wxString version;
+    if(!m_doc.GetRoot()->GetAttribute("Version", &version)) {
+        m_doc.GetRoot()->AddAttribute("Version", WORKSPACE_XML_VERSION);
+    }
+    
     bool ok = m_doc.Save(sos);
 
     wxFFile file(m_fileName.GetFullPath(), wxT("w+b"));
@@ -436,8 +446,7 @@ wxString Project::GetFiles(bool absPath)
     GetFiles(files, absPath);
 
     wxString temp;
-    for(size_t i = 0; i < files.size(); i++)
-        temp << wxT("\"") << files.at(i).GetFullPath() << wxT("\" ");
+    for(size_t i = 0; i < files.size(); i++) temp << wxT("\"") << files.at(i).GetFullPath() << wxT("\" ");
 
     if(temp.IsEmpty() == false) temp.RemoveLast();
 
@@ -581,7 +590,8 @@ void Project::CopyTo(const wxString& new_path, const wxString& new_name, const w
 
     // update the 'Name' property
     XmlUtils::UpdateProperty(doc.GetRoot(), wxT("Name"), new_name);
-
+    XmlUtils::UpdateProperty(doc.GetRoot(), "Version", WORKSPACE_XML_VERSION);
+    
     // set description
     wxXmlNode* descNode(NULL);
 
@@ -931,8 +941,8 @@ void Project::DoGetVirtualDirectories(wxXmlNode* parent, TreeNode<wxString, Visu
     }
 }
 
-TreeNode<wxString, VisualWorkspaceNode>*
-Project::GetVirtualDirectories(TreeNode<wxString, VisualWorkspaceNode>* workspace)
+TreeNode<wxString, VisualWorkspaceNode>* Project::GetVirtualDirectories(
+    TreeNode<wxString, VisualWorkspaceNode>* workspace)
 {
     VisualWorkspaceNode data;
     data.name = GetName();
@@ -1175,15 +1185,18 @@ wxString Project::GetBestPathForVD(const wxString& vdPath)
     return basePath;
 }
 
-wxArrayString Project::GetIncludePaths(bool clearCache)
+wxArrayString Project::GetIncludePaths()
 {
-    wxArrayString paths;
+    if(!m_cachedIncludePaths.IsEmpty()) {
+        return m_cachedIncludePaths;
+    }
 
     BuildMatrixPtr matrix = GetWorkspace()->GetBuildMatrix();
     if(!matrix) {
-        return paths;
+        return m_cachedIncludePaths;
     }
 
+    wxStringSet_t paths;
     wxString workspaceSelConf = matrix->GetSelectedConfigurationName();
 
     wxString projectSelConf = matrix->GetProjectSelectedConf(workspaceSelConf, GetName());
@@ -1192,11 +1205,7 @@ wxArrayString Project::GetIncludePaths(bool clearCache)
     // for non custom projects, take the settings from the build configuration
     if(buildConf) {
         // Apply the environment
-        EnvSetter es(NULL, NULL, GetName(), buildConf->GetName());
-
-        if(clearCache) {
-            s_backticks.clear();
-        }
+        EnvSetter es(this);
 
         // Get the include paths and add them
         wxString projectIncludePaths = buildConf->GetIncludePath();
@@ -1211,12 +1220,14 @@ wxArrayString Project::GetIncludePaths(bool clearCache)
                 fn = wxFileName(GetFileName().GetPath(), wxT(""));
 
             } else {
-                fn = projectIncludePathsArr.Item(i);
+                wxString includePath = projectIncludePathsArr.Item(i);
+                includePath = MacroManager::Instance()->Expand(includePath, NULL, GetName(), buildConf->GetName());
+                fn = includePath;
                 if(fn.IsRelative()) {
                     fn.MakeAbsolute(GetFileName().GetPath());
                 }
             }
-            paths.Add(fn.GetFullPath());
+            paths.insert(fn.GetFullPath());
         }
 
         // get the compiler options and add them
@@ -1241,11 +1252,16 @@ wxArrayString Project::GetIncludePaths(bool clearCache)
             // unchanged
             wxArrayString includePaths = DoBacktickToIncludePath(cmpOption);
             if(!includePaths.IsEmpty()) {
-                paths.insert(paths.end(), includePaths.begin(), includePaths.end());
+                std::for_each(includePaths.begin(), includePaths.end(), [&](const wxString& path) {
+                    wxFileName fn(path, "");
+                    paths.insert(fn.GetPath());
+                });
             }
         }
     }
-    return paths;
+
+    std::for_each(paths.begin(), paths.end(), [&](const wxString& path) { m_cachedIncludePaths.Add(path); });
+    return m_cachedIncludePaths;
 }
 
 wxArrayString Project::DoBacktickToPreProcessors(const wxString& backtick)
@@ -1297,11 +1313,8 @@ void Project::ClearAllVirtDirs()
 
 wxString Project::GetProjectIconName() const { return m_doc.GetRoot()->GetPropVal(wxT("IconIndex"), "gear16"); }
 
-void Project::GetReconciliationData(wxString& toplevelDir,
-                                    wxString& extensions,
-                                    wxArrayString& ignoreFiles,
-                                    wxArrayString& excludePaths,
-                                    wxArrayString& regexes)
+void Project::GetReconciliationData(wxString& toplevelDir, wxString& extensions, wxArrayString& ignoreFiles,
+    wxArrayString& excludePaths, wxArrayString& regexes)
 {
     if(!m_doc.IsOk()) {
         return;
@@ -1339,11 +1352,8 @@ void Project::GetReconciliationData(wxString& toplevelDir,
     }
 }
 
-void Project::SetReconciliationData(const wxString& toplevelDir,
-                                    const wxString& extensions,
-                                    const wxArrayString& ignoreFiles,
-                                    const wxArrayString& excludePaths,
-                                    wxArrayString& regexes)
+void Project::SetReconciliationData(const wxString& toplevelDir, const wxString& extensions,
+    const wxArrayString& ignoreFiles, const wxArrayString& excludePaths, wxArrayString& regexes)
 {
     if(!m_doc.IsOk()) {
         return;
@@ -1532,8 +1542,8 @@ wxArrayString Project::GetExcludeConfigForFile(const wxString& filename, const w
     return configs;
 }
 
-void
-Project::SetExcludeConfigForFile(const wxString& filename, const wxString& virtualDirPath, const wxArrayString& configs)
+void Project::SetExcludeConfigForFile(
+    const wxString& filename, const wxString& virtualDirPath, const wxArrayString& configs)
 {
     wxXmlNode* vdNode = GetVirtualDir(virtualDirPath);
     if(!vdNode) {
@@ -1699,7 +1709,7 @@ void Project::CreateCompileCommandsJSON(JSONElement& compile_commands)
     }
 }
 
-BuildConfigPtr Project::GetBuildConfiguration(const wxString& configName)
+BuildConfigPtr Project::GetBuildConfiguration(const wxString& configName) const
 {
     BuildMatrixPtr matrix = GetWorkspace()->GetBuildMatrix();
     if(!matrix) {
@@ -1873,7 +1883,6 @@ wxArrayString Project::DoGetCompilerOptions(bool cxxOptions, bool clearCache, bo
 
 void Project::ProjectRenamed(const wxString& oldname, const wxString& newname)
 {
-    std::map<wxString, wxArrayString> configs;
     // dependencies are located directly under the root level
     wxXmlNode* node = m_doc.GetRoot()->GetChildren();
     while(node) {
@@ -1892,14 +1901,64 @@ void Project::ProjectRenamed(const wxString& oldname, const wxString& newname)
         }
         node = node->GetNext();
     }
-    
+
     if(GetName() == oldname) {
         // Update the name
         XmlUtils::UpdateProperty(m_doc.GetRoot(), "Name", newname);
     }
 }
 
-void Project::ClearBacktickCache()
+void Project::ClearBacktickCache() { s_backticks.clear(); }
+
+void Project::GetUnresolvedMacros(const wxString& configName, wxArrayString& vars) const
 {
-    s_backticks.clear();
+    vars.clear();
+    BuildConfigPtr buildConfig = GetBuildConfiguration(configName);
+    if(buildConfig) {
+        // Check for environment variables
+        // Environment variable has the format of $(VAR_NAME)
+        static wxRegEx reEnvironmentVar("\\$\\(([a-z0-9_]+)\\)", wxRE_ICASE | wxRE_ADVANCED);
+
+        wxString includePaths = buildConfig->GetIncludePath();
+        wxString libPaths = buildConfig->GetLibPath();
+        if(reEnvironmentVar.IsValid()) {
+            // Check the include paths
+            includePaths = MacroManager::Instance()->Expand(includePaths, clGetManager(), GetName(), configName);
+            while(true) {
+                if(reEnvironmentVar.Matches(includePaths)) {
+                    size_t start, len;
+                    if(reEnvironmentVar.GetMatch(&start, &len, 1)) {
+                        wxString envVarName = includePaths.Mid(start, len);
+                        includePaths = includePaths.Mid(start + len);
+                        vars.Add(envVarName);
+                        continue;
+                    }
+                }
+                break;
+            }
+
+            // Check the include lib paths
+            libPaths = MacroManager::Instance()->Expand(libPaths, clGetManager(), GetName(), configName);
+            while(true) {
+                if(reEnvironmentVar.Matches(libPaths)) {
+                    size_t start, len;
+                    if(reEnvironmentVar.GetMatch(&start, &len, 1)) {
+                        wxString envVarName = libPaths.Mid(start, len);
+                        libPaths = includePaths.Mid(start + len);
+                        vars.Add(envVarName);
+                        continue;
+                    }
+                }
+                break;
+            }
+        }
+    }
+}
+
+void Project::ClearIncludePathCache() { m_cachedIncludePaths.clear(); }
+
+wxString Project::GetVersion() const
+{
+    if(!m_doc.IsOk() || m_doc.GetRoot()) return wxEmptyString;
+    return m_doc.GetRoot()->GetAttribute("Version");
 }
