@@ -213,7 +213,7 @@ bool VcImporter::ConvertProject(VcProjectData& data)
     // now we can create the project
     wxFileName fn(data.filepath);
     fn.MakeAbsolute();
-    if(!clCxxWorkspaceST::Get()->CreateProject(data.name, fn.GetPath(), projectType, true, errMsg)) {
+    if(!clCxxWorkspaceST::Get()->CreateProject(data.name, fn.GetPath(), projectType, "", true, errMsg)) {
         return false;
     }
 
