@@ -72,11 +72,11 @@ void wxCustomStatusBarFieldText::SetText(const wxString& text)
 {
     m_text = text;
     // Render the new text
-    if(m_rect != wxRect() && m_parent) {
+    if((m_rect != wxRect()) && m_parent) {
         // valid rect
         wxCustomStatusBarArt::Ptr_t art = m_parent->GetArt();
         if(art->GetName() == m_parent->GetLastArtNameUsedForPaint()) {
-#ifdef __WXOSX__
+#if defined(__WXOSX__) || defined(__WXMSW__)
             m_parent->Refresh();
             return;
 #endif
@@ -182,8 +182,10 @@ void wxCustomStatusBarBitmapField::Render(wxDC& dc, const wxRect& rect, wxCustom
 
     // Center bitmap
     if(m_bitmap.IsOk()) {
-        wxCoord bmpY = (rect.GetHeight() - m_bitmap.GetHeight()) / 2 + rect.y;
-        wxCoord bmpX = (rect.GetWidth() - m_bitmap.GetWidth()) / 2 + rect.x;
+        int bmpHeight = m_bitmap.GetScaledHeight();
+        int bmpWidth = m_bitmap.GetScaledWidth();
+        wxCoord bmpY = (rect.GetHeight() - bmpHeight) / 2 + rect.y;
+        wxCoord bmpX = (rect.GetWidth() - bmpWidth) / 2 + rect.x;
         // Draw the bitmap
         dc.DrawBitmap(m_bitmap, bmpX, bmpY + 1);
     }
@@ -324,7 +326,7 @@ void wxCustomStatusBar::OnLeftDown(wxMouseEvent& event)
             clCommandEvent event(wxEVT_STATUSBAR_CLICKED);
             event.SetEventObject(this);
             event.SetInt(i);
-            GetEventHandler()->AddPendingEvent(event);
+            GetEventHandler()->ProcessEvent(event);
             break;
         }
     }
@@ -385,7 +387,7 @@ void wxCustomStatusBar::AnimationClicked(wxCustomStatusBarField* field)
             clCommandEvent event(wxEVT_STATUSBAR_CLICKED);
             event.SetEventObject(this);
             event.SetInt(i);
-            GetEventHandler()->AddPendingEvent(event);
+            GetEventHandler()->ProcessEvent(event);
             break;
         }
     }
