@@ -8,30 +8,27 @@
 class clMakeGeneratorApp : public wxAppConsole
 {
 public:
-    enum eCommandType {
-        kBuild,
-        kClean,
-        kRebuild
-    };
-    
+    enum eCommandType { kBuild, kClean, kRebuild };
+
 protected:
-    wxString     m_workspaceFile;
-    wxString     m_project;
-    wxString     m_workingDirectory;
-    wxString     m_configuration;
-    bool         m_verbose;
-    bool         m_executeCommand;
-    int          m_exitCode;
+    wxString m_workspaceFile;
+    wxString m_project;
+    wxString m_workingDirectory;
+    wxString m_configuration;
+    bool m_verbose;
+    bool m_executeCommand;
+    int m_exitCode;
     eCommandType m_commandType;
-    
+    wxString m_buildSettingsXml;
+
 protected:
     bool DoParseCommandLine(wxCmdLineParser& parser);
-    void DoExecCommand(const wxString &command);
+    void DoExecCommand(const wxString& command);
 
-    void Notice(const wxString &msg);
-    void Error(const wxString &msg);
-    void Info(const wxString &msg);
-    void Out(const wxString &msg);
+    void Notice(const wxString& msg);
+    void Error(const wxString& msg);
+    void Info(const wxString& msg);
+    void Out(const wxString& msg);
 
 public:
     clMakeGeneratorApp();
