@@ -13,7 +13,8 @@ PHPConfigurationData::PHPConfigurationData()
     , m_flags(kRunLintOnFileSave)
     , m_xdebugIdeKey("codeliteide")
     , m_xdebugHost("127.0.0.1")
-    , m_findInFilesMask("*.php;*.inc;*.phtml;*.js;*.html;*.css;*.scss;*.json;*.xml;*.ini;*.md;*.txt;*.text;.htaccess")
+    , m_findInFilesMask(
+          "*.php;*.inc;*.phtml;*.js;*.html;*.css;*.scss;*.json;*.xml;*.ini;*.md;*.txt;*.text;.htaccess;*.sql")
     , m_workspaceType(0)
     , m_settersGettersFlags(kSG_None)
 {
