@@ -5,6 +5,7 @@
 #include <wx/dir.h>
 
 PHPParserThread* PHPParserThread::ms_instance = 0;
+bool PHPParserThread::ms_goingDown = false;
 
 PHPParserThread::PHPParserThread() {}
 
@@ -25,6 +26,7 @@ void PHPParserThread::Release()
         delete ms_instance;
     }
     ms_instance = 0;
+    ms_goingDown = false;
 }
 
 void PHPParserThread::ProcessRequest(ThreadRequest* request)
@@ -48,7 +50,7 @@ void PHPParserThread::ParseFiles(PHPParserThreadRequest* request)
     wxFileName fnWorkspaceFile(request->workspaceFile);
     bool isFull = request->requestType == PHPParserThreadRequest::kParseWorkspaceFilesFull;
     wxUnusedVar(isFull);
-    
+
     wxStringSet_t uniqueFilesSet;
     uniqueFilesSet.insert(request->files.begin(), request->files.end());
 
@@ -57,6 +59,10 @@ void PHPParserThread::ParseFiles(PHPParserThreadRequest* request)
     lookuptable.Open(fnWorkspaceFile.GetPath());
 
     for(size_t i = 0; i < request->frameworksPaths.GetCount(); ++i) {
+        if(ms_goingDown) {
+            ms_goingDown = false;
+            return;
+        }
         wxArrayString frameworkFiles;
         wxDir::GetAllFiles(request->frameworksPaths.Item(i), &frameworkFiles, "*.php", wxDIR_DIRS | wxDIR_FILES);
         uniqueFilesSet.insert(frameworkFiles.begin(), frameworkFiles.end());
@@ -74,7 +80,10 @@ void PHPParserThread::ParseFiles(PHPParserThreadRequest* request)
                                         request->requestType == PHPParserThreadRequest::kParseWorkspaceFilesFull ?
                                             PHPLookupTable::kUpdateMode_Full :
                                             PHPLookupTable::kUpdateMode_Fast,
+                                        [&]() { return PHPParserThread::ms_goingDown; },
                                         false);
+    // reset the shutdown flag
+    ms_goingDown = false;
 }
 
 void PHPParserThread::ParseFile(PHPParserThreadRequest* request)
@@ -91,3 +100,10 @@ void PHPParserThread::ParseFile(PHPParserThreadRequest* request)
     // Save its symbols
     lookuptable.UpdateSourceFile(sourceFile);
 }
+
+void PHPParserThread::Clear()
+{
+    ms_goingDown = true;
+    // Clear the queue
+    Instance()->m_queue.Clear();
+}
