@@ -85,7 +85,6 @@ PhpPlugin::PhpPlugin(IManager* manager)
 
     // Instantiate the bitmaps, we do this so they will be populated in wxXmlResource
     // Sigleton class
-    PHPImages images;
     PHPWorkspace::Get()->SetPluginManager(m_mgr);
     XDebugManager::Initialize(this);
 
@@ -127,7 +126,9 @@ PhpPlugin::PhpPlugin(IManager* manager)
     EventNotifier::Get()->Connect(
         wxEVT_CMD_GET_WORKSPACE_FILES, wxCommandEventHandler(PhpPlugin::OnGetWorkspaceFiles), NULL, this);
     EventNotifier::Get()->Connect(wxEVT_CMD_GET_CURRENT_FILE_PROJECT_FILES,
-        wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles), NULL, this);
+                                  wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles),
+                                  NULL,
+                                  this);
     EventNotifier::Get()->Connect(
         wxEVT_CMD_GET_ACTIVE_PROJECT_FILES, wxCommandEventHandler(PhpPlugin::OnGetActiveProjectFiles), NULL, this);
     EventNotifier::Get()->Connect(
@@ -161,7 +162,7 @@ PhpPlugin::PhpPlugin(IManager* manager)
         PHPConfigurationData config;
         if(!fnSampleFile.Exists() || // the sample file does not exists
                                      // Or the resource file (PHP.zip) is newer than the sample file
-            (phpResources.GetModificationTime().GetTicks() > fnSampleFile.GetModificationTime().GetTicks())) {
+           (phpResources.GetModificationTime().GetTicks() > fnSampleFile.GetModificationTime().GetTicks())) {
 
             targetDir.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
             zipReader.Extract("*", targetDir.GetPath());
@@ -249,7 +250,9 @@ void PhpPlugin::UnPlug()
     EventNotifier::Get()->Disconnect(
         wxEVT_CMD_FIND_IN_FILES_DISMISSED, clCommandEventHandler(PhpPlugin::OnFindInFilesDismissed), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_CMD_GET_CURRENT_FILE_PROJECT_FILES,
-        wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles), NULL, this);
+                                     wxCommandEventHandler(PhpPlugin::OnGetCurrentFileProjectFiles),
+                                     NULL,
+                                     this);
     EventNotifier::Get()->Disconnect(
         wxEVT_CMD_GET_ACTIVE_PROJECT_FILES, wxCommandEventHandler(PhpPlugin::OnGetActiveProjectFiles), NULL, this);
     EventNotifier::Get()->Disconnect(wxEVT_FILE_SAVED, clCommandEventHandler(PhpPlugin::OnFileSaved), NULL, this);
@@ -274,7 +277,7 @@ void PhpPlugin::UnPlug()
     // Close any open workspace
     if(PHPWorkspace::Get()->IsOpen()) {
         PHPWorkspace::Get()->Close(true, false);
-        m_workspaceView->UnLoadWorkspace();
+        m_workspaceView->UnLoadWorkspaceView();
     }
 
     m_workspaceView->Destroy();
@@ -314,7 +317,8 @@ void PhpPlugin::OnNewWorkspace(clCommandEvent& e)
             wxFileName workspaceFile(newWspDlg.GetWorkspacePath());
             if(!workspaceFile.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL)) {
                 ::wxMessageBox(wxString::Format(_("Could not create workspace folder:\n%s"), workspaceFile.GetPath()),
-                    "CodeLite", wxICON_ERROR | wxOK | wxCENTER);
+                               "CodeLite",
+                               wxICON_ERROR | wxOK | wxCENTER);
                 return;
             }
             PHPWorkspace::Get()->Create(newWspDlg.GetWorkspacePath());
@@ -340,7 +344,7 @@ void PhpPlugin::OnCloseWorkspace(clCommandEvent& e)
 
         m_mgr->EnableClangCodeCompletion(m_clangOldFlag);
         PHPWorkspace::Get()->Close(true, true);
-        m_workspaceView->UnLoadWorkspace();
+        m_workspaceView->UnLoadWorkspaceView();
 
         // notify codelite to close the currently opened workspace
         wxCommandEvent eventClose(wxEVT_COMMAND_MENU_SELECTED, wxID_CLOSE_ALL);
@@ -392,9 +396,11 @@ void PhpPlugin::DoOpenWorkspace(const wxString& filename, bool createIfMissing,
     FRAME->GetEventHandler()->ProcessEvent(eventClose);
 
     // Open the PHP workspace
-    if(!PHPWorkspace::Get()->Open(filename, createIfMissing)) {
-        wxMessageBox(_("Failed to open workspace: corrupted workspace file"), wxT("CodeLite"),
-            wxOK | wxICON_WARNING | wxCENTER, FRAME);
+    if(!PHPWorkspace::Get()->Open(filename, m_workspaceView, createIfMissing)) {
+        wxMessageBox(_("Failed to open workspace: corrupted workspace file"),
+                     wxT("CodeLite"),
+                     wxOK | wxICON_WARNING | wxCENTER,
+                     FRAME);
         return;
     }
 
@@ -403,7 +409,7 @@ void PhpPlugin::DoOpenWorkspace(const wxString& filename, bool createIfMissing,
     m_clangOldFlag = (options.GetClangOptions() & CC_CLANG_ENABLED);
 
     m_mgr->EnableClangCodeCompletion(false);
-    m_workspaceView->LoadWorkspace();
+    m_workspaceView->LoadWorkspaceView();
 
     // Select the 'PHP' tab
     m_mgr->GetWorkspaceView()->SelectPage(PHPStrings::PHP_WORKSPACE_VIEW_LABEL);
@@ -431,8 +437,10 @@ void PhpPlugin::OnOpenResource(wxCommandEvent& e)
                 IEditor* editor = m_mgr->OpenFile(itemData->filename.GetFullPath());
                 if(editor) {
                     if(itemData->line != wxNOT_FOUND) {
-                        if(!editor->FindAndSelect(itemData->displayName, itemData->displayName,
-                               editor->PosFromLine(itemData->line), NULL)) {
+                        if(!editor->FindAndSelect(itemData->displayName,
+                                                  itemData->displayName,
+                                                  editor->PosFromLine(itemData->line),
+                                                  NULL)) {
                             editor->CenterLine(itemData->line);
                         }
                     }
@@ -529,10 +537,16 @@ void PhpPlugin::DoPlaceMenuBar(wxMenuBar* menuBar)
         menuBar->Insert(helpLoc, phpMenuBarMenu, _("P&HP"));
     }
 
-    phpMenuBarMenu->Connect(wxID_PHP_SETTINGS, wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(PhpPlugin::OnMenuCommand), NULL, (wxEvtHandler*)this);
-    phpMenuBarMenu->Connect(wxID_PHP_RUN_XDEBUG_DIAGNOSTICS, wxEVT_COMMAND_MENU_SELECTED,
-        wxCommandEventHandler(PhpPlugin::OnRunXDebugDiagnostics), NULL, (wxEvtHandler*)this);
+    phpMenuBarMenu->Connect(wxID_PHP_SETTINGS,
+                            wxEVT_COMMAND_MENU_SELECTED,
+                            wxCommandEventHandler(PhpPlugin::OnMenuCommand),
+                            NULL,
+                            (wxEvtHandler*)this);
+    phpMenuBarMenu->Connect(wxID_PHP_RUN_XDEBUG_DIAGNOSTICS,
+                            wxEVT_COMMAND_MENU_SELECTED,
+                            wxCommandEventHandler(PhpPlugin::OnRunXDebugDiagnostics),
+                            NULL,
+                            (wxEvtHandler*)this);
 }
 
 void PhpPlugin::OnMenuCommand(wxCommandEvent& e)
@@ -773,21 +787,24 @@ void PhpPlugin::FinalizeStartup()
     // Create the debugger windows (hidden)
     wxWindow* parent = m_mgr->GetDockingManager()->GetManagedWindow();
     m_debuggerPane = new PHPDebugPane(parent);
-    m_mgr->GetDockingManager()->AddPane(m_debuggerPane, wxAuiPaneInfo()
-                                                            .Name("XDebug")
-                                                            .Caption("Call Stack & Breakpoints")
-                                                            .Hide()
-                                                            .CloseButton()
-                                                            .MaximizeButton()
-                                                            .Bottom()
-                                                            .Position(3));
+    m_mgr->GetDockingManager()->AddPane(m_debuggerPane,
+                                        wxAuiPaneInfo()
+                                            .Name("XDebug")
+                                            .Caption("Call Stack & Breakpoints")
+                                            .Hide()
+                                            .CloseButton()
+                                            .MaximizeButton()
+                                            .Bottom()
+                                            .Position(3));
 
     m_xdebugLocalsView = new LocalsView(parent);
-    m_mgr->GetDockingManager()->AddPane(m_xdebugLocalsView,
+    m_mgr->GetDockingManager()->AddPane(
+        m_xdebugLocalsView,
         wxAuiPaneInfo().Name("XDebugLocals").Caption("Locals").Hide().CloseButton().MaximizeButton().Bottom());
 
     m_xdebugEvalPane = new EvalPane(parent);
-    m_mgr->GetDockingManager()->AddPane(m_xdebugEvalPane,
+    m_mgr->GetDockingManager()->AddPane(
+        m_xdebugEvalPane,
         wxAuiPaneInfo().Name("XDebugEval").Caption("PHP").Hide().CloseButton().MaximizeButton().Bottom().Position(2));
 
     // Check to see if the have a PHP executable setup
@@ -851,8 +868,8 @@ void PhpPlugin::OnFileSysetmUpdated(clFileSystemEvent& event)
 {
     event.Skip();
     if(PHPWorkspace::Get()->IsOpen()) {
-        PHPWorkspace::Get()->SyncWithFileSystem();
-        m_workspaceView->LoadWorkspace();
+        // Sync the workspace view, notify the view when its done
+        PHPWorkspace::Get()->SyncWithFileSystemAsync(m_workspaceView);
     }
 }
 
@@ -869,6 +886,13 @@ void PhpPlugin::OnSaveSession(clCommandEvent& event)
 void PhpPlugin::DoSyncFileWithRemote(const wxFileName& localFile)
 {
     // Check to see if we got a remote-upload setup
+    PHPProject::Ptr_t pProject = PHPWorkspace::Get()->GetProjectForFile(localFile);
+    if(!pProject) {
+        // Not a workspace file
+        clDEBUG() << localFile << "is not a PHP workspace file, will not sync it with remote" << clEndl;
+        return;
+    }
+    
     SSHWorkspaceSettings settings;
     settings.Load();
 
