@@ -51,7 +51,7 @@ static Cscope* thePlugin = NULL;
 static const wxString CSCOPE_NAME = _("CScope");
 
 // Define the plugin entry point
-extern "C" EXPORT IPlugin* CreatePlugin(IManager* manager)
+CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
     if(thePlugin == 0) {
         thePlugin = new Cscope(manager);
@@ -59,20 +59,17 @@ extern "C" EXPORT IPlugin* CreatePlugin(IManager* manager)
     return thePlugin;
 }
 
-extern "C" EXPORT PluginInfo GetPluginInfo()
+CL_PLUGIN_API PluginInfo* GetPluginInfo()
 {
-    PluginInfo info;
+    static PluginInfo info;
     info.SetAuthor(wxT("Eran Ifrah, patched by Stefan Roesch"));
     info.SetName(CSCOPE_NAME);
     info.SetDescription(_("CScope Integration for CodeLite"));
     info.SetVersion(wxT("v1.1"));
-    return info;
+    return &info;
 }
 
-extern "C" EXPORT int GetPluginInterfaceVersion()
-{
-    return PLUGIN_INTERFACE_VERSION;
-}
+CL_PLUGIN_API int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
 
 Cscope::Cscope(IManager* manager)
     : IPlugin(manager)
@@ -84,7 +81,9 @@ Cscope::Cscope(IManager* manager)
 
     m_cscopeWin = new CscopeTab(m_mgr->GetOutputPaneNotebook(), m_mgr);
     m_mgr->GetOutputPaneNotebook()->AddPage(
-        m_cscopeWin, CSCOPE_NAME, false, wxXmlResource::Get()->LoadBitmap(wxT("cscope")));
+        m_cscopeWin, CSCOPE_NAME, false, m_mgr->GetStdIcons()->LoadBitmap("cscope"));
+    m_tabHelper.reset(new clTabTogglerHelper(CSCOPE_NAME, m_cscopeWin, "", NULL));
+    m_tabHelper->SetOutputTabBmp(m_mgr->GetStdIcons()->LoadBitmap("cscope"));
 
     Connect(wxEVT_CSCOPE_THREAD_DONE, wxCommandEventHandler(Cscope::OnCScopeThreadEnded), NULL, this);
     Connect(wxEVT_CSCOPE_THREAD_UPDATE_STATUS, wxCommandEventHandler(Cscope::OnCScopeThreadUpdateStatus), NULL, this);
@@ -107,9 +106,7 @@ Cscope::Cscope(IManager* manager)
     EventNotifier::Get()->Bind(wxEVT_CONTEXT_MENU_EDITOR, &Cscope::OnEditorContentMenu, this);
 }
 
-Cscope::~Cscope()
-{
-}
+Cscope::~Cscope() {}
 
 clToolBar* Cscope::CreateToolBar(wxWindow* parent)
 {
@@ -118,41 +115,25 @@ clToolBar* Cscope::CreateToolBar(wxWindow* parent)
 
     clToolBar* tb = NULL;
     if(m_mgr->AllowToolbar()) {
-        tb = new clToolBar(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, clTB_DEFAULT_STYLE);
+        tb = new clToolBar(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, clTB_DEFAULT_STYLE_PLUGIN);
         tb->SetToolBitmapSize(wxSize(size, size));
 
         // Sample code that adds single button to the toolbar
         // and associates an image to it
         BitmapLoader* bitmapLoader = m_mgr->GetStdIcons();
-        if(size == 24) {
-            // use the large icons set
-            tb->AddTool(XRCID("cscope_find_symbol"),
-                        _("Find this C symbol"),
-                        bitmapLoader->LoadBitmap(wxT("toolbars/24/cscope/find_symbol")),
-                        _("Find this C symbol"));
-            tb->AddTool(XRCID("cscope_functions_calling_this_function"),
-                        _("Find functions calling this function"),
-                        bitmapLoader->LoadBitmap(wxT("toolbars/24/cscope/function_calling_this_function")),
-                        _("Find functions calling this function"));
-            tb->AddTool(XRCID("cscope_functions_called_by_this_function"),
-                        _("Find functions called by this function"),
-                        bitmapLoader->LoadBitmap(wxT("toolbars/24/cscope/functions_called_by_this_function")),
-                        _("Find functions called by this function"));
-        } else {
-            // 16
-            tb->AddTool(XRCID("cscope_find_symbol"),
-                        _("Find this C symbol"),
-                        bitmapLoader->LoadBitmap(wxT("toolbars/16/cscope/find_symbol")),
-                        _("Find this C symbol"));
-            tb->AddTool(XRCID("cscope_functions_calling_this_function"),
-                        _("Find functions calling this function"),
-                        bitmapLoader->LoadBitmap(wxT("toolbars/16/cscope/function_calling_this_function")),
-                        _("Find functions calling this function"));
-            tb->AddTool(XRCID("cscope_functions_called_by_this_function"),
-                        _("Find functions called by this function"),
-                        bitmapLoader->LoadBitmap(wxT("toolbars/16/cscope/functions_called_by_this_function")),
-                        _("Find functions called by this function"));
-        }
+        // use the large icons set
+        tb->AddTool(XRCID("cscope_find_symbol"),
+                    _("Find this C symbol"),
+                    bitmapLoader->LoadBitmap("find", size),
+                    _("Find this C symbol"));
+        tb->AddTool(XRCID("cscope_functions_calling_this_function"),
+                    _("Find functions calling this function"),
+                    bitmapLoader->LoadBitmap("step_in", size),
+                    _("Find functions calling this function"));
+        tb->AddTool(XRCID("cscope_functions_called_by_this_function"),
+                    _("Find functions called by this function"),
+                    bitmapLoader->LoadBitmap("step_out", size),
+                    _("Find functions called by this function"));
         tb->Realize();
     }
 
@@ -297,6 +278,7 @@ void Cscope::CreatePluginMenu(wxMenu* pluginsMenu)
 
 void Cscope::UnPlug()
 {
+    m_tabHelper.reset(NULL);
     m_topWindow->Disconnect(XRCID("cscope_functions_called_by_this_function"),
                             wxEVT_UPDATE_UI,
                             wxUpdateUIEventHandler(Cscope::OnCscopeUI),
@@ -773,8 +755,7 @@ void Cscope::OnWorkspaceOpenUI(wxUpdateUIEvent& e)
 void Cscope::OnFindUserInsertedSymbol(wxCommandEvent& WXUNUSED(e))
 {
     wxString word = GetSearchPattern();
-    if(word.IsEmpty())
-        return;
+    if(word.IsEmpty()) return;
 
     DoFindSymbol(word);
 }
