@@ -23,7 +23,7 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 #include "cscopestatusmessage.h"
- #include "procutils.h"
+#include "procutils.h"
 #include "dirsaver.h"
 #include "wx/filefn.h"
 #include "cscopedbbuilderthread.h"
@@ -48,7 +48,7 @@ void CscopeDbBuilderThread::ProcessRequest(ThreadRequest *request)
 	DirSaver ds;
 
 	wxSetWorkingDirectory(req->GetWorkingDir());
-	SendStatusEvent( wxT("Executing cscope..."), 10, req->GetFindWhat(), req->GetOwner() );
+	SendStatusEvent( _("Executing cscope..."), 10, req->GetFindWhat(), req->GetOwner() );
 
 	//notify the database creation process as completed
 	wxArrayString output;
@@ -56,10 +56,10 @@ void CscopeDbBuilderThread::ProcessRequest(ThreadRequest *request)
 	//set environment variables required by cscope
 	wxSetEnv(wxT("TMPDIR"), wxFileName::GetTempDir());
 	ProcUtils::SafeExecuteCommand(req->GetCmd(), output);
-	SendStatusEvent( wxT("Parsing results..."), 50, wxEmptyString, req->GetOwner() );
+	SendStatusEvent( _("Parsing results..."), 50, wxEmptyString, req->GetOwner() );
 
-	CscopeResultTable *result = ParseResults( output );
-	SendStatusEvent( wxT("Done"), 100, wxEmptyString, req->GetOwner() );
+	CScopeResultTable_t *result = ParseResults( output );
+	SendStatusEvent( _("Done"), 100, wxEmptyString, req->GetOwner() );
 
 	// send status message
 	SendStatusEvent(req->GetEndMsg(), 100, wxEmptyString, req->GetOwner());
@@ -70,9 +70,9 @@ void CscopeDbBuilderThread::ProcessRequest(ThreadRequest *request)
 	req->GetOwner()->AddPendingEvent(e);
 }
 
-CscopeResultTable* CscopeDbBuilderThread::ParseResults(const wxArrayString &output)
+CScopeResultTable_t* CscopeDbBuilderThread::ParseResults(const wxArrayString &output)
 {
-	CscopeResultTable *results = new CscopeResultTable();
+	CScopeResultTable_t *results = new CScopeResultTable_t();
 	for (size_t i=0; i< output.GetCount(); i++) {
 		//parse each line
 		wxString line = output.Item(i);
@@ -106,7 +106,7 @@ CscopeResultTable* CscopeDbBuilderThread::ParseResults(const wxArrayString &outp
 		data.SetPattern(pattern);
 
 		//insert the result
-		CscopeResultTable::const_iterator iter = results->find(data.GetFile());
+		CScopeResultTable_t::const_iterator iter = results->find(data.GetFile());
 		std::vector< CscopeEntryData > *vec(NULL);
 		if (iter != results->end()) {
 			//this file already exist, append the result
