@@ -25,19 +25,21 @@
 #ifndef __cscopedbbuilderthread__
 #define __cscopedbbuilderthread__
 
-
+#include <wx/string.h>
+#include <wx/gdicmn.h>
+#include "wx/thread.h"
+#include "wx/event.h"
 #include "cscopeentrydata.h"
 #include "singleton.h"
 #include "worker_thread.h"
-#include "wx/thread.h"
-#include "wx/event.h"
 #include <map>
 #include <vector>
 
 extern int wxEVT_CSCOPE_THREAD_DONE;
 extern int wxEVT_CSCOPE_THREAD_UPDATE_STATUS;
 
-typedef std::map<wxString, std::vector< CscopeEntryData >* > CscopeResultTable;
+typedef std::vector< CscopeEntryData > CScopeEntryDataVec_t;
+typedef std::map<wxString, CScopeEntryDataVec_t* > CScopeResultTable_t;
 
 /**
  * \class CscopeRequest
@@ -105,7 +107,7 @@ class CscopeDbBuilderThread : public WorkerThread
 	friend class Singleton< CscopeDbBuilderThread >;
 protected:
 	void ProcessRequest(ThreadRequest *req);
-	CscopeResultTable* ParseResults(const wxArrayString &output);
+	CScopeResultTable_t* ParseResults(const wxArrayString &output);
 
 protected:
 	void SendStatusEvent(const wxString &msg, int percent, const wxString &findWhat, wxEvtHandler *owner);
